/**
 * BLOCK: Accordion - Save Block
 */

import classnames from "classnames";
import React from "react";
import Style from "style-it";

import generateCSS from "../../../generateCSS";
import generateCSSUnit from "../../../generateCSSUnit";
import { hexToRgba } from "../../../utils/index.js";

function styling(props) {
  const {
    block_id,
    layout,
    inactiveOtherItems,
    expandFirstItem,
    rowsGap,
    columnsGap,
    align,
    borderStyle,
    borderWidth,
    borderRadius,
    borderColor,
    titleTextColor,
    titleTextActiveColor,
    titlePaddingTypeDesktop,
    vtitlePaddingMobile,
    vtitlePaddingTablet,
    vtitlePaddingDesktop,
    htitlePaddingMobile,
    htitlePaddingTablet,
    htitlePaddingDesktop,
    contentTextColor,
    contentPaddingTypeDesktop,
    vcontentPaddingMobile,
    vcontentPaddingTablet,
    vcontentPaddingDesktop,
    hcontentPaddingMobile,
    hcontentPaddingTablet,
    hcontentPaddingDesktop,
    iconColor,
    iconActiveColor,
    iconHoverColor,
    titleFontWeight,
    titleFontSize,
    titleLineHeight,
    contentFontWeight,
    contentFontSize,
    contentLineHeight,
    iconAlign,
    iconSize,
    iconSizeType,
    iconSizeMobile,
    iconSizeTablet,
    columns,
    titleLeftPaddingTablet,
    titleBottomPaddingTablet,
    titleLeftPaddingDesktop,
    titleBottomPaddingDesktop,
    titleLeftPaddingMobile,
    titleBottomPaddingMobile,
    headingTag,
    titleBackgroundColorOpacity,
    marginV,
    marginH,
    titleSecondaryBackgroundColor,
    titleGradientDegree,
    titleBgGradient,
    titleBackgroundColor,
    contentSecondaryBackgroundColor,
    contentGradientDegree,
    contentBgGradient,
    contentBackgroundColor,
    contentBackgroundColorOpacity,
  } = props.attributes;

  var selectors = {};
  var tablet_selectors = {};
  var mobile_selectors = {};
  var icon_color = iconColor;
  var icon_active_color = iconActiveColor;

  if ("undefined" == typeof iconColor || "" == iconColor) {
    icon_color = titleTextColor;
  }
  if ("undefined" == typeof iconActiveColor || "" == iconActiveColor) {
    icon_active_color = titleTextActiveColor;
  }

  let contentOpacity = titleBackgroundColorOpacity / 100;
  let contentBackgroundColorsOpacity = contentBackgroundColorOpacity / 100;

  var temptitleSecondaryBackgroundColor = titleBgGradient
    ? titleSecondaryBackgroundColor
    : titleBackgroundColor;

  var titleGradient =
    "linear-gradient(" +
    titleGradientDegree +
    "deg," +
    hexToRgba(titleBackgroundColor || "#ffffff", contentOpacity || 0) +
    "," +
    hexToRgba(
      temptitleSecondaryBackgroundColor || "#ffffff",
      contentOpacity || 0
    ) +
    ")";

  var tempActiveSecondaryBackgroundColor = contentBgGradient
    ? contentSecondaryBackgroundColor
    : contentBackgroundColor;

  var contentGradient =
    "linear-gradient(" +
    contentGradientDegree +
    "deg," +
    hexToRgba(
      contentBackgroundColor || "#ffffff",
      contentBackgroundColorOpacity || 0
    ) +
    "," +
    hexToRgba(
      tempActiveSecondaryBackgroundColor || "#ffffff",
      contentBackgroundColorsOpacity || 0
    ) +
    ")";

  selectors = {
    " ": {
      "margin-top": marginV + "px",
      "margin-bottom": marginV + "px",
      "margin-left": marginH + "px",
      "margin-right": marginH + "px",
    },
    " .responsive-block-editor-addons-icon svg": {
      width: generateCSSUnit(iconSize, iconSizeType),
      height: generateCSSUnit(iconSize, iconSizeType),
      "font-size": generateCSSUnit(iconSize, iconSizeType),
      fill: icon_color,
      "margin-right": "10px",
    },
    " .responsive-block-editor-addons-icon-active svg": {
      width: generateCSSUnit(iconSize, iconSizeType),
      height: generateCSSUnit(iconSize, iconSizeType),
      "font-size": generateCSSUnit(iconSize, iconSizeType),
      fill: icon_active_color,
      "margin-right": "10px",
    },

    " .responsive-block-editor-addons-icon svg:hover": {
      fill: iconHoverColor + "!important",
    },

    " .responsive-block-editor-addons-icon-active svg:hover": {
      fill: iconHoverColor + "!important",
    },

    " .responsive-block-editor-addons-accordion-item__outer-wrap": {
      "margin-bottom": generateCSSUnit(rowsGap, "px"),
    },
    " .responsive-block-editor-addons-accordion__wrap.responsive-block-editor-addons-buttons-layout-wrap": {
      "grid-column-gap": generateCSSUnit(columnsGap, "px"),
      "grid-row-gap": generateCSSUnit(rowsGap, "px"),
    },
    " .responsive-block-editor-addons-accordion-item": {
      "border-style": borderStyle,
      "border-width": generateCSSUnit(borderWidth, "px"),
      "border-radius": generateCSSUnit(borderRadius, "px"),
      "border-color": borderColor,
    },
    " .responsive-block-editor-addons-accordion-titles-button": {
      "padding-top": generateCSSUnit(
        vtitlePaddingDesktop,
        titlePaddingTypeDesktop
      ),
      "padding-bottom": generateCSSUnit(
        titleBottomPaddingDesktop,
        titlePaddingTypeDesktop
      ),
      "padding-right": generateCSSUnit(
        htitlePaddingDesktop,
        titlePaddingTypeDesktop
      ),
      "padding-left": generateCSSUnit(
        titleLeftPaddingDesktop,
        titlePaddingTypeDesktop
      ),
    },
    " .responsive-block-editor-addons-accordion-content span": {
      "margin-top": generateCSSUnit(
        vcontentPaddingDesktop,
        contentPaddingTypeDesktop
      ),
      "margin-bottom": generateCSSUnit(
        vcontentPaddingDesktop,
        contentPaddingTypeDesktop
      ),
      "margin-right": generateCSSUnit(
        hcontentPaddingDesktop,
        contentPaddingTypeDesktop
      ),
      "margin-left": generateCSSUnit(
        hcontentPaddingDesktop,
        contentPaddingTypeDesktop
      ),
    },
    " .responsive-block-editor-addons-accordion-item:hover .responsive-block-editor-addons-icon svg": {
      fill: icon_active_color,
    },
    " .responsive-block-editor-addons-accordion-item .responsive-block-editor-addons-accordion-titles-button.responsive-block-editor-addons-accordion-titles": {
      "flex-direction": iconAlign,
    },
    " .responsive-block-editor-addons-accordion-titles-button ": {
      "background-image": titleGradient,
    },
    " .responsive-block-editor-addons-accordion-titles-button .responsive-block-editor-addons-title": {
      color: titleTextColor,
      "font-size": titleFontSize + "px",
      "line-height": titleLineHeight,
      "font-weight": titleFontWeight,
    },
    " .responsive-block-editor-addons-accordion-item .responsive-block-editor-addons-accordion-content": {
      "background-image": contentGradient,
      "font-size": contentFontSize + "px",
      "line-height": contentLineHeight,
      "font-weight": contentFontWeight,
      color: contentTextColor,
    },
  };

  tablet_selectors = {
    " .responsive-block-editor-addons-accordion-titles-button": {
      "padding-top": generateCSSUnit(
        vtitlePaddingTablet,
        titlePaddingTypeDesktop
      ),
      "padding-bottom": generateCSSUnit(
        titleBottomPaddingTablet,
        titlePaddingTypeDesktop
      ),
      "padding-right": generateCSSUnit(
        htitlePaddingTablet,
        titlePaddingTypeDesktop
      ),
      "padding-left": generateCSSUnit(
        titleLeftPaddingTablet,
        titlePaddingTypeDesktop
      ),
    },
    " .responsive-block-editor-addons-accordion-content span": {
      "margin-top": generateCSSUnit(
        vcontentPaddingTablet,
        contentPaddingTypeDesktop
      ),
      "margin-bottom": generateCSSUnit(
        vcontentPaddingTablet,
        contentPaddingTypeDesktop
      ),
      "margin-right": generateCSSUnit(
        hcontentPaddingTablet,
        contentPaddingTypeDesktop
      ),
      "margin-left": generateCSSUnit(
        hcontentPaddingTablet,
        contentPaddingTypeDesktop
      ),
    },
    " .responsive-block-editor-addons-icon svg": {
      width: generateCSSUnit(iconSizeTablet, iconSizeType),
      height: generateCSSUnit(iconSizeTablet, iconSizeType),
      "font-size": generateCSSUnit(iconSizeTablet, iconSizeType),
    },
    " .responsive-block-editor-addons-icon-active svg": {
      width: generateCSSUnit(iconSizeTablet, iconSizeType),
      height: generateCSSUnit(iconSizeTablet, iconSizeType),
      "font-size": generateCSSUnit(iconSizeTablet, iconSizeType),
    },
  };

  mobile_selectors = {
    " .responsive-block-editor-addons-accordion-titles-button": {
      "padding-top": generateCSSUnit(
        vtitlePaddingMobile,
        titlePaddingTypeDesktop
      ),
      "padding-bottom": generateCSSUnit(
        titleBottomPaddingMobile,
        titlePaddingTypeDesktop
      ),
      "padding-right": generateCSSUnit(
        htitlePaddingMobile,
        titlePaddingTypeDesktop
      ),
      "padding-left": generateCSSUnit(
        titleLeftPaddingMobile,
        titlePaddingTypeDesktop
      ),
    },
    " .responsive-block-editor-addons-accordion-content span": {
      "margin-top": generateCSSUnit(
        vcontentPaddingMobile,
        contentPaddingTypeDesktop
      ),
      "margin-bottom": generateCSSUnit(
        vcontentPaddingMobile,
        contentPaddingTypeDesktop
      ),
      "margin-right": generateCSSUnit(
        hcontentPaddingMobile,
        contentPaddingTypeDesktop
      ),
      "margin-left": generateCSSUnit(
        hcontentPaddingMobile,
        contentPaddingTypeDesktop
      ),
    },
    " .responsive-block-editor-addons-icon svg": {
      width: generateCSSUnit(iconSizeMobile, iconSizeType),
      height: generateCSSUnit(iconSizeMobile, iconSizeType),
      "font-size": generateCSSUnit(iconSizeMobile, iconSizeType),
    },
    " .responsive-block-editor-addons-icon-active svg": {
      width: generateCSSUnit(iconSizeMobile, iconSizeType),
      height: generateCSSUnit(iconSizeMobile, iconSizeType),
      "font-size": generateCSSUnit(iconSizeMobile, iconSizeType),
    },
  };

  if ("accordion" === layout && true === inactiveOtherItems) {
    selectors[
      " .responsive-block-editor-addons-accordion-item__outer-wrap .responsive-block-editor-addons-accordion-content "
    ] = {
      display: "none",
    };
  }
  if ("accordion" === layout && false === inactiveOtherItems) {
    (selectors[
      " .responsive-block-editor-addons-accordion-item__outer-wrap .responsive-block-editor-addons-accordion-item .responsive-block-editor-addons-accordion-titles-button .responsive-block-editor-addons-icon-active"
    ] = {
      display: "inline-block",
    }),
      (selectors[
        " .responsive-block-editor-addons-accordion-item__outer-wrap .responsive-block-editor-addons-accordion-item .responsive-block-editor-addons-accordion-titles-button .responsive-block-editor-addons-icon"
      ] = {
        display: "none",
      });
  }
  if ("accordion" === layout && true === expandFirstItem) {
    selectors[
      "  > div:first-child > .responsive-block-editor-addons-accordion-item__outer-wrap .responsive-block-editor-addons-accordion-content "
    ] = {
      display: "block",
    };
    (selectors[
      "  > div:first-child > .responsive-block-editor-addons-accordion-item__outer-wrap .responsive-block-editor-addons-accordion-item .responsive-block-editor-addons-accordion-titles-button .responsive-block-editor-addons-icon-active "
    ] = {
      display: "inline-block",
    }),
      (selectors[
        "  > div:first-child > .responsive-block-editor-addons-accordion-item__outer-wrap .responsive-block-editor-addons-accordion-item .responsive-block-editor-addons-accordion-titles-button .responsive-block-editor-addons-icon "
      ] = {
        display: "none",
      });
  }
  if ("grid" === layout) {
    selectors[
      "  .responsive-block-editor-addons-accordion-item__outer-wrap "
    ] = {
      "text-align": align,
    };
    selectors[
      " .responsive-block-editor-addons-accordion__wrap.responsive-block-editor-addons-buttons-layout-wrap "
    ] = {
      "grid-template-columns": "repeat(" + columns + ", 1fr)",
      display: "grid",
    };
  }

  var styling_css = "";
  var id = `.responsive-block-editor-addons-block-${block_id}`;

  styling_css = generateCSS(selectors, id);

  styling_css += generateCSS(tablet_selectors, id, true, "tablet");

  styling_css += generateCSS(mobile_selectors, id, true, "mobile");

  return styling_css;
}

const { InnerBlocks } = wp.blockEditor;

export default function save(props) {
  const { className } = props;
  const { block_id, schema, equalHeight } = props.attributes;

  const equalHeightClass = equalHeight
    ? "responsive-block-editor-addons-accordion-equal-height"
    : "";

  return (
    <div
      className={classnames(
        className,
        "responsive-block-editor-addons-accordion__outer-wrap",
        `responsive-block-editor-addons-block-${block_id}`,
        `responsive-block-editor-addons-accordion-icon-${props.attributes.iconAlign}`,
        `responsive-block-editor-addons-accordion-layout-${props.attributes.layout}`,
        `responsive-block-editor-addons-accordion-expand-first-${props.attributes.expandFirstItem}`,
        `responsive-block-editor-addons-accordion-inactive-other-${props.attributes.inactiveOtherItems}`,
        equalHeightClass
      )}
    >
      <Style>{styling(props)}</Style>
      <div className="responsive-block-editor-addons-accordion__wrap responsive-block-editor-addons-buttons-layout-wrap">
        <InnerBlocks.Content />
      </div>
    </div>
  );
}
