/**
 * Internal dependencies
 */
import classnames from "classnames";
import Inspector from "./inspector";
import generateCSSUnit from "../../../../generateCSSUnit";
import generateBackgroundImageEffect from "../../../../generateBackgroundImageEffect";
import Style from "style-it";
import { hexToRgba } from "../../../../utils";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const { InnerBlocks } = wp.editor;

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: {
        width,
        topPadding,
        bottomPadding,
        leftPadding,
        rightPadding,
        topMargin,
        bottomMargin,
        leftMargin,
        rightMargin,
        backgroundColor,
        backgroundColor1,
        backgroundColor2,
        colorLocation1,
        colorLocation2,
        gradientDirection,
        backgroundType,
        backgroundImage,
        opacity,
        blockBorderStyle,
        blockBorderWidth,
        blockBorderRadius,
        blockBorderColor,
        boxShadowColor,
        boxShadowHOffset,
        boxShadowVOffset,
        boxShadowBlur,
        boxShadowSpread,
        boxShadowPosition,
        blockId,
      },
      setAttributes,
    } = this.props;
    setAttributes({ blockId: this.props.clientId });
    var boxShadowPositionCSS = boxShadowPosition;

    if ("outset" === boxShadowPosition) {
      boxShadowPositionCSS = "";
    }
    let imgopacity = opacity / 100;
    return [
      // Show the block controls on focus

      <Inspector {...{ setAttributes, ...this.props }} />,
      <Fragment>
        <Style>
          {`
            #block-${blockId}.block-editor-block-list__block {
                width: ${width}%;

            }
            `}
        </Style>
        {backgroundType == "image" && backgroundImage && (
          <Style>
            {`
 #block-${blockId} .responsive-block-editor-addons-block-column{
	      background-image: linear-gradient(${hexToRgba(
          "#fff",
          1 - imgopacity || 0
        )},${hexToRgba("#fff", 1 - imgopacity || 0)}),url(${backgroundImage});
          
	  }
        `}
          </Style>
        )}
      </Fragment>,
      <div
        className={classnames(
          "responsive-column-wrap",
          "responsive-block-editor-addons-block-column"
        )}
        style={{
          paddingTop: topPadding,
          paddingBottom: bottomPadding,
          paddingLeft: leftPadding,
          paddingRight: rightPadding,
          marginTop: topMargin,
          marginBottom: bottomMargin,
          marginLeft: leftMargin,
          marginRight: rightMargin,
          borderWidth: generateCSSUnit(blockBorderWidth, "px"),
          borderColor: blockBorderColor,
          borderStyle: blockBorderStyle,
          borderRadius: blockBorderRadius,
          backgroundColor:
            backgroundType == "color"
              ? `${hexToRgba(backgroundColor || "#fff", imgopacity || 0)}`
              : undefined,
          backgroundImage:
            backgroundType == "gradient"
              ? generateBackgroundImageEffect(
                  `${hexToRgba(backgroundColor1 || "#fff", imgopacity || 0)}`,
                  `${hexToRgba(backgroundColor2 || "#fff", imgopacity || 0)}`,
                  gradientDirection,
                  colorLocation1,
                  colorLocation2
                )
              : undefined,
          boxShadow:
            generateCSSUnit(boxShadowHOffset, "px") +
            " " +
            generateCSSUnit(boxShadowVOffset, "px") +
            " " +
            generateCSSUnit(boxShadowBlur, "px") +
            " " +
            generateCSSUnit(boxShadowSpread, "px") +
            " " +
            boxShadowColor +
            " " +
            boxShadowPositionCSS,
        }}
      >
        <div className="responsive-column-inner-wrap">
          <InnerBlocks templateLock={false} />
        </div>
      </div>,
    ];
  }
}
