/**
 * BLOCK: Responsive Blocks Column
 */

// Import block dependencies and components
import Edit from "./components/edit";
import Save from "./components/save";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Internationalization
const { __ } = wp.i18n;

// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("responsive-block-editor-addons/column", {
  title: __("Column", "responsive-block-editor-addons"),
  description: __(
    "This block is an immediate child of Advanced Columns.",
    "responsive-block-editor-addons"
  ),
  icon: "layout",
  category: "responsive_block_editor_addons",
  parent: ["responsive-block-editor-addons/advance-columns"],
  keywords: [
    __("calendar", "responsive-block-editor-addons"),
    __("date", "responsive-block-editor-addons"),
    __("responsive", "responsive-block-editor-addons"),
  ],
  attributes: {
    width: {
      type: "number",
      default: 50,
    },
    topPadding: {
      type: "number",
    },
    bottomPadding: {
      type: "number",
    },
    leftPadding: {
      type: "number",
    },
    rightPadding: {
      type: "number",
    },
    leftMargin: {
      type: "number",
    },
    rightMargin: {
      type: "number",
    },
    topMargin: {
      type: "number",
    },
    bottomMargin: {
      type: "number",
    },
    blockId: {
      type: "string",
    },
    blockBorderStyle: {
      type: "string",
      default: "none",
    },
    blockBorderWidth: {
      type: "number",
      default: 1,
    },
    blockBorderRadius: {
      type: "number",
    },
    blockBorderColor: {
      type: "string",
    },
    boxShadowColor: {
      type: "string",
    },
    boxShadowHOffset: {
      type: "number",
      default: 20,
    },
    boxShadowVOffset: {
      type: "number",
      default: 20,
    },
    boxShadowBlur: {
      type: "number",
      default: 50,
    },
    boxShadowSpread: {
      type: "number",
      default: 20,
    },
    boxShadowPosition: {
      type: "string",
      default: "outset",
    },
    opacity: {
      type: "number",
      default: 20,
    },
    colorLocation1: {
      type: "number",
      default: 0,
    },
    colorLocation2: {
      type: "number",
      default: 100,
    },
    gradientDirection: {
      type: "number",
      default: 90,
    },
    backgroundImage: {
      type: "string",
    },
    backgroundType: {
      type: "string",
    },
    backgroundColor: {
      type: "string",
    },
    backgroundColor1: {
      type: "string",
    },
    backgroundColor2: {
      type: "string",
      default: "#fff",
    },
  },

  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
