/**
 * Internal dependencies
 */
import classnames from "classnames";
import Inspector from "./inspector";
import Style from "style-it";
/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const {
  RichText,
  AlignmentToolbar,
  BlockControls,
  MediaUpload,
  InnerBlocks,
  MediaUploadCheck,
  figure,
} = wp.editor;
const { Button, Dashicon } = wp.components;

const ALLOWED_MEDIA_TYPES = ["image"];

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: {
        headingTitle,
        headingDesc,
        seperatorStyle,
        headSpacing,
        separatorSpacing,
        separatorHeight,
        separatorWidth,
        separatorColor,
        headingTitleFontSize,
        headingTitleFontSizeTablet,
        headingTitleFontSizeMobile,
        headingTitleFontWeight,
        headingTitleLineHeight,
        headingTitleLetterSpacing,
        headingTitleColor,
        subHeadingTitleFontSize,
        subHeadingTitleFontSizeMobile,
        subHeadingTitleFontSizeTablet,
        subHeadingTitleFontWeight,
        subHeadingTitleLineHeight,
        subHeadingTitleLetterSpacing,
        subHeadingTitleColor,
        headingTag,
        level,
        headingAlignment,
        showHeading,
        showSubHeading,
        showSeparator,
          block_id,
      },
      setAttributes,
      mergeBlocks,
      insertBlocksAfter,
      onReplace,
    } = this.props;
      this.props.setAttributes({ block_id: this.props.clientId });
    return [
      <BlockControls key="controls">
        <AlignmentToolbar
          value={headingAlignment}
          onChange={(value) => setAttributes({ headingAlignment: value })}
        />
      </BlockControls>,
      // Show the block controls on focus
      <Inspector {...{ setAttributes, ...this.props }} />,
      <Style>
        {`
@media only screen and (min-width: 976px){
.responsive-block-editor-addons-block-advanced-heading.block-${this.props.clientId} .responsive-heading-title-text {
	font-size: ${headingTitleFontSize}px !important;
		}
}
@media only screen and (max-width: 976px){
.responsive-block-editor-addons-block-advanced-heading.block-${this.props.clientId} .responsive-heading-title-text {
	font-size: ${headingTitleFontSizeTablet}px;
		}
}
@media only screen and (max-width: 767px){
	.responsive-block-editor-addons-block-advanced-heading.block-${this.props.clientId} .responsive-heading-title-text {
	font-size: ${headingTitleFontSizeMobile}px;
		}
}
`}
      </Style>,

      // Show the block markup in the editor
      <div
        className={classnames(
          "responsive-block-editor-addons-block-advanced-heading",
            `block-${this.props.clientId}`,
        )}
        style={{
          textAlign: headingAlignment,
        }}
      >
        {showHeading && (
          <RichText
            tagName={headingTag}
            placeholder={__("Write a Heading")}
            value={headingTitle}
            className="responsive-heading-title-text"
            multiline={false}
            onChange={(value) => {
              setAttributes({ headingTitle: value });
            }}
            style={{
              fontWeight: headingTitleFontWeight,
              lineHeight: headingTitleLineHeight,
              letterSpacing: headingTitleLetterSpacing,
              color: headingTitleColor,
              marginBottom: headSpacing,
            }}
            onMerge={mergeBlocks}
            unstableOnSplit={
              insertBlocksAfter
                ? (before, after, ...blocks) => {
                    setAttributes({ content: before });
                    insertBlocksAfter([
                      ...blocks,
                      createBlock("core/paragraph", { content: after }),
                    ]);
                  }
                : undefined
            }
            onRemove={() => onReplace([])}
          />
        )}
        {seperatorStyle !== "none" && showSeparator && (
          <div className="responsive-heading-seperator-wrap">
            <div
              className="responsive-heading-seperator"
              style={{
                marginBottom: separatorSpacing,
                borderTopStyle: seperatorStyle,
                borderTopWidth: separatorHeight,
                width: separatorWidth,
                borderColor: separatorColor,
              }}
            ></div>
          </div>
        )}
        {showSubHeading && (
          <RichText
            tagName="p"
            placeholder={__("Write a Description")}
            value={headingDesc}
            className="responsive-heading-desc-text"
            onChange={(value) => setAttributes({ headingDesc: value })}
            onMerge={mergeBlocks}
            unstableOnSplit={this.splitBlock}
            onRemove={() => onReplace([])}
            style={{
              fontSize: subHeadingTitleFontSize,
              fontWeight: subHeadingTitleFontWeight,
              lineHeight: subHeadingTitleLineHeight,
              letterSpacing: subHeadingTitleLetterSpacing,
              color: subHeadingTitleColor,
            }}
          />
        )}
      </div>,
    ];
  }
}
