/**
 * Internal dependencies
 */
import classnames from "classnames";
import Style from "style-it";

/**
 * WordPress dependencies
 */
const { Component } = wp.element;
const { RichText } = wp.editor;

export default class Save extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    const {
      headingTitle,
      headingId,
      headingDesc,
      seperatorStyle,
      headSpacing,
      separatorSpacing,
      separatorHeight,
      separatorWidth,
      separatorColor,
      headingTitleFontSize,
      headingTitleFontSizeTablet,
      headingTitleFontSizeMobile,

      headingTitleFontWeight,
      headingTitleLineHeight,
      headingTitleLetterSpacing,
      headingTitleColor,
      subHeadingTitleFontSize,
      subHeadingTitleFontSizeMobile,
      subHeadingTitleFontSizeTablet,
      subHeadingTitleFontWeight,
      subHeadingTitleLineHeight,
      subHeadingTitleLetterSpacing,
      subHeadingTitleColor,
      headingTag,
      level,
      headingAlignment,
      showHeading,
      showSubHeading,
      showSeparator,
        block_id
    } = this.props.attributes;

    var seprator_output = "";
    if (seperatorStyle !== "none") {
      seprator_output = (
        <div className="responsive-heading-seperator-wrap">
          <div
            className="responsive-heading-seperator"
            style={{
              marginBottom: separatorSpacing,
              borderTopStyle: seperatorStyle,
              borderTopWidth: separatorHeight,
              width: separatorWidth,
              borderColor: separatorColor,
            }}
          ></div>
        </div>
      );
    }
    return [
      <Style>
        {`
@media only screen and (min-width: 976px){
.responsive-block-editor-addons-block-advanced-heading.block-${block_id} .responsive-heading-title-text {
	font-size: ${headingTitleFontSize}px;
		}
}
@media only screen and (max-width: 976px){
.responsive-block-editor-addons-block-advanced-heading.block-${block_id} .responsive-heading-title-text {
	font-size: ${headingTitleFontSizeTablet}px;
		}
}
@media only screen and (max-width: 767px){
	.responsive-block-editor-addons-block-advanced-heading.block-${block_id} .responsive-heading-title-text {
	font-size: ${headingTitleFontSizeMobile}px;
		}
}

`}
      </Style>,
      <div
        className={classnames(
          "responsive-block-editor-addons-block-advanced-heading",
            `block-${block_id}`,
        )}
        style={{
          textAlign: headingAlignment,
        }}
      >
        {showHeading && (
          <RichText.Content
            tagName={headingTag}
            value={headingTitle}
            className="responsive-heading-title-text"
            id={headingId}
            style={{
              fontWeight: headingTitleFontWeight,
              lineHeight: headingTitleLineHeight,
              letterSpacing: headingTitleLetterSpacing,
              color: headingTitleColor,
              marginBottom: headSpacing,
            }}
          />
        )}
        {showSeparator && seprator_output}
        {showSubHeading && (
          <RichText.Content
            tagName="p"
            value={headingDesc}
            className="responsive-heading-desc-text"
            style={{
              fontSize: subHeadingTitleFontSize,
              fontWeight: subHeadingTitleFontWeight,
              lineHeight: subHeadingTitleLineHeight,
              letterSpacing: subHeadingTitleLetterSpacing,
              color: subHeadingTitleColor,
            }}
          />
        )}
      </div>,
    ];
  }
}
