/**
 * Internal dependencies
 */
import classnames from "classnames";
import Inspector from "./inspector";
import Buttons from "./buttons";
import icons from "./../../../../utils/components/icons";
import React from "react";
import Style from "style-it";
import generateBackgroundImageEffect from "../../../../generateBackgroundImageEffect";
import ResponsiveBlocksIcon from "../../../../ResponsiveBlocksIcon.json";
import renderSVG from "../../../../renderIcon";
import generateCSSUnit from "../../../../generateCSSUnit";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const {
  RichText,
  AlignmentToolbar,
  BlockControls,
  InnerBlocks,
  InspectorControls,
  URLInput,
} = wp.editor;
const {
  Button,
  Icon,
  Dashicon,
  BaseControl,
  PanelBody,
  RangeControl,
  SelectControl,
  ToolbarButton,
  ToolbarGroup,
  ToggleControl,
} = wp.components;

const ALLOWED_BLOCKS = ["responsive-block-editor-addons/buttons"];

let svg_icons = Object.keys(ResponsiveBlocksIcon);

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: {
        counterId,
        buttonAlignment,
        label,
        link,
        iconsize,
        vPadding,
        hPadding,
        vMargin,
        hMargin,
        borderWidth,
        borderRadius,
        borderStyle,
        borderColor,
        borderHColor,
        color,
        background,
        hColor,
        sizeType,
        sizeMobile,
        sizeTablet,
        lineHeight,
        lineHeightType,
        lineHeightMobile,
        lineHeightTablet,
        opensInNewTab,
        target,
        backgroundColor1,
        backgroundColor2,
        colorLocation1,
        colorLocation2,
        gradientDirection,
        backgroundType,
        opacity,
        icon,
        iconPosition,
        buttonFontSize,
        buttonLineHeight,
        buttonFontWeight,
        boxShadowColor,
        boxShadowHOffset,
        boxShadowVOffset,
        boxShadowBlur,
        boxShadowSpread,
        boxShadowPosition,
        hoverEffect,
        icon_color,
        hbackground,
        iconSpace,
        inheritFromTheme,
      },
      isSelected,
      setAttributes,
    } = this.props;

    setAttributes({ counterId: this.props.clientId });

    var element = document.getElementById(
      "responsive-block-editor-addons-style-button-child-" + this.props.clientId
    );

    let imgopacity = opacity / 100;

    var boxShadowPositionCSS = boxShadowPosition;

    if ("outset" === boxShadowPosition) {
      boxShadowPositionCSS = "";
    }

    return (
      <Fragment>
        <Inspector {...{ setAttributes, ...this.props }} />
        {!inheritFromTheme && (
          <Fragment>
            <Style>
              {`
            .responsive-block-editor-addons-${counterId}.responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__link, .edit-post-visual-editor.editor-styles-wrapper .wp-block-cover .responsive-block-editor-addons-${counterId}.responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__link {
                color: ${color};
            }
            .responsive-block-editor-addons-${counterId}.responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__link:hover, .edit-post-visual-editor.editor-styles-wrapper .wp-block-cover .responsive-block-editor-addons-${counterId}.responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__link:hover {
                color: ${hColor};
            }
			.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper {
				border-color: ${borderColor};
				padding-top: ${generateCSSUnit(vPadding, "px")};
				padding-bottom: ${generateCSSUnit(vPadding, "px")};
				padding-left: ${generateCSSUnit(hPadding, "px")};
				padding-right: ${generateCSSUnit(hPadding, "px")};
				margin-top: ${generateCSSUnit(vMargin, "px")};
				margin-bottom: ${generateCSSUnit(vMargin, "px")};
				margin-left: ${generateCSSUnit(hMargin, "px")};
				margin-right: ${generateCSSUnit(hMargin, "px")};
				border-radius: ${generateCSSUnit(borderRadius, "px")};
				border-style: ${borderStyle};
				border-width: ${generateCSSUnit(borderWidth, "px")};
				font-size: ${generateCSSUnit(buttonFontSize, "px")};
				font-weight: ${buttonFontWeight};
				line-height: ${buttonLineHeight};
				opacity: ${imgopacity};
				box-shadow: ${
          generateCSSUnit(boxShadowHOffset, "px") +
          " " +
          generateCSSUnit(boxShadowVOffset, "px") +
          " " +
          generateCSSUnit(boxShadowBlur, "px") +
          " " +
          generateCSSUnit(boxShadowSpread, "px") +
          " " +
          boxShadowColor +
          " " +
          boxShadowPositionCSS
        };
			}
			.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper:hover {
				border-color: ${borderHColor};
			}
        `}
            </Style>
            {backgroundType == "color" && (
              <Style>
                {`
		  .responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper {
			  background-color: ${background};
		  }
		  .responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper:hover {
			  background-color: ${hbackground};
		  }
	  `}
              </Style>
            )}
            {backgroundType == "gradient" && (
              <Style>
                {`
		  .responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper {
			  background-image: ${generateBackgroundImageEffect(
          backgroundColor1,
          backgroundColor2,
          gradientDirection,
          colorLocation1,
          colorLocation2
        )};
		  }
	  `}
              </Style>
            )}
          </Fragment>
        )}
        <Style>
          {`
		.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__icon svg{
			fill: ${icon_color};
			width: ${generateCSSUnit(iconsize, "px")};
		   height: ${generateCSSUnit(iconsize, "px")};
		}
	`}
        </Style>
        <Buttons {...this.props}>
          <div
            className={classnames(
              `responsive-block-editor-addons-${counterId}`,
              "responsive-block-editor-addons-button__wrapper",
              `responsive-block-editor-addons-button__effect-${hoverEffect}`,
              inheritFromTheme ? "wp-block-button" : null
            )}
          >
            <div
              className={classnames(
                "responsive-block-editor-addons-buttons-repeater",
                "responsive-block-editor-addons-button__wrapper",
                inheritFromTheme ? "wp-block-button__link" : null
              )}
            >
              {"" !== icon && iconPosition == "before" && (
                <span
                  className={classnames(
                    `responsive-block-editor-addons-button__icon`,
                    `responsive-block-editor-addons-button__icon-position-${iconPosition}`
                  )}
                  style={{
                    marginRight: iconSpace,
                  }}
                >
                  {renderSVG(icon)}
                </span>
              )}
              <RichText
                placeholder={__("Add text…", "responsive-block-editor-addons")}
                value={label}
                tagName="a"
                onChange={(value) => {
                  setAttributes({ label: value });
                }}
                allowedFormats={["bold", "italic", "strikethrough"]}
                className="responsive-block-editor-addons-button__link"
                rel={target ? "noopener noreferrer" : null}
                target={target ? "_blank" : null}
                hoverEffect={hoverEffect}
                keepPlaceholderOnFocus
              />
              {"" !== icon && iconPosition == "after" && (
                <span
                  className={classnames(
                    `responsive-block-editor-addons-button__icon`,
                    `responsive-block-editor-addons-button__icon-position-${iconPosition}`
                  )}
                  style={{
                    marginLeft: iconSpace,
                  }}
                >
                  {renderSVG(icon)}
                </span>
              )}
            </div>
          </div>
          {isSelected && (
            <form
              key="form-link"
              className={`blocks-button__inline-link ab-button`}
              onSubmit={(event) => event.preventDefault()}
            >
              <Dashicon icon={"admin-links"} />
              <URLInput
                className="button-url"
                value={link}
                onChange={(value) => setAttributes({ link: value })}
              />
              <Button
                label={__("Apply", "responsive-block-editor-addons")}
                type="submit"
              >
                <Icon icon="editor-break" />
              </Button>
            </form>
          )}
        </Buttons>
      </Fragment>
    );
  }
}
