/**
 * Internal dependencies
 */
import Buttons from "./buttons";
import React from "react";
import Style from "style-it";
import classnames from "classnames";
import generateBackgroundImageEffect from "../../../../generateBackgroundImageEffect";
import ResponsiveBlocksIcon from "../../../../ResponsiveBlocksIcon.json";
import renderSVG from "../../../../renderIcon";
import generateCSSUnit from "../../../../generateCSSUnit";

/**
 * WordPress dependencies
 */
const { Component, Fragment } = wp.element;
const { RichText } = wp.editor;

let svg_icons = Object.keys(ResponsiveBlocksIcon);

export default class Save extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      counterId,
      label,
      target,
      link,
      iconsize,
      vPadding,
      hPadding,
      vMargin,
      hMargin,
      borderWidth,
      borderRadius,
      borderStyle,
      borderColor,
      borderHColor,
      color,
      background,
      hColor,
      sizeType,
      sizeMobile,
      sizeTablet,
      lineHeight,
      lineHeightType,
      lineHeightMobile,
      lineHeightTablet,
      backgroundColor1,
      backgroundColor2,
      colorLocation1,
      colorLocation2,
      gradientDirection,
      backgroundType,
      opacity,
      icon,
      iconPosition,
      buttonFontSize,
      buttonLineHeight,
      buttonFontWeight,
      boxShadowColor,
      boxShadowHOffset,
      boxShadowVOffset,
      boxShadowBlur,
      boxShadowSpread,
      boxShadowPosition,
      hoverEffect,
      icon_color,
      hbackground,
      iconSpace,
      inheritFromTheme,
    } = this.props.attributes;

    let imgopacity = opacity / 100;

    var boxShadowPositionCSS = boxShadowPosition;

    if ("outset" === boxShadowPosition) {
      boxShadowPositionCSS = "";
    }

    return [
      <Fragment>
        {!inheritFromTheme && (
          <Fragment>
            <Style type="text/css">
              {`
                  .responsive-block-editor-addons-${counterId}.responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__link_child {
                      color: ${color};
                   }
                  .responsive-block-editor-addons-${counterId}.responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__link_child:hover {
                       color: ${hColor};
                   }
				   .responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper {
	   				border-color: ${borderColor};
					padding-top: ${generateCSSUnit(vPadding, "px")};
					padding-bottom: ${generateCSSUnit(vPadding, "px")};
					padding-left: ${generateCSSUnit(hPadding, "px")};
					padding-right: ${generateCSSUnit(hPadding, "px")};
					margin-top: ${generateCSSUnit(vMargin, "px")};
					margin-bottom: ${generateCSSUnit(vMargin, "px")};
					margin-left: ${generateCSSUnit(hMargin, "px")};
					margin-right: ${generateCSSUnit(hMargin, "px")};
					border-radius: ${generateCSSUnit(borderRadius, "px")};
					border-style: ${borderStyle};
					border-width: ${generateCSSUnit(borderWidth, "px")};
					font-size: ${generateCSSUnit(buttonFontSize, "px")};
	   				font-weight: ${buttonFontWeight};
	   				line-height: ${buttonLineHeight};
	   				opacity: ${imgopacity};
	   				box-shadow: ${
              generateCSSUnit(boxShadowHOffset, "px") +
              " " +
              generateCSSUnit(boxShadowVOffset, "px") +
              " " +
              generateCSSUnit(boxShadowBlur, "px") +
              " " +
              generateCSSUnit(boxShadowSpread, "px") +
              " " +
              boxShadowColor +
              " " +
              boxShadowPositionCSS
            };
	   			}
	   			.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-button__wrapper:hover {
	   				border-color: ${borderHColor};
	   			}

           `}
            </Style>
            {backgroundType == "color" && (
              <Style type="text/css">
                {`
		.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper {
			background-color: ${background};
		}
		.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper:hover {
			background-color: ${hbackground};
		}
	`}
              </Style>
            )}
            {backgroundType == "gradient" && (
              <Style>
                {`
		.responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-buttons-repeater.responsive-block-editor-addons-button__wrapper {
			background-image: ${generateBackgroundImageEffect(
        backgroundColor1,
        backgroundColor2,
        gradientDirection,
        colorLocation1,
        colorLocation2
      )};
		}
	`}
              </Style>
            )}
          </Fragment>
        )}

        <Style>
          {`
	  .responsive-block-editor-addons-${counterId} .responsive-block-editor-addons-button__wrapper .responsive-block-editor-addons-button__icon svg{
		  fill: ${icon_color};
		  width: ${generateCSSUnit(iconsize, "px")};
		 height: ${generateCSSUnit(iconsize, "px")};
	  }
  `}
        </Style>
      </Fragment>,
      <Buttons {...this.props}>
        <div
          className={classnames(
            `responsive-block-editor-addons-${counterId}`,
            "responsive-block-editor-addons-button__wrapper",
            `responsive-block-editor-addons-button__effect-${hoverEffect}`,
            inheritFromTheme ? "wp-block-button" : null
          )}
        >
          <div
            className={classnames(
              "responsive-block-editor-addons-buttons-repeater",
              "responsive-block-editor-addons-button__wrapper",
              inheritFromTheme ? "wp-block-button__link" : null
            )}
          >
            {"" !== icon && iconPosition == "before" && (
              <span
                className={classnames(
                  `responsive-block-editor-addons-button__icon`,
                  `responsive-block-editor-addons-button__icon-position-${iconPosition}`
                )}
                style={{
                  marginRight: iconSpace,
                }}
              >
                {renderSVG(icon)}
              </span>
            )}
            <RichText.Content
              value={label}
              tagName="a"
              className="responsive-block-editor-addons-button__link_child"
              href={link}
              hoverEffect={hoverEffect}
              rel={target ? "noopener noreferrer" : null}
              target={target ? "_blank" : null}
            />
            {"" !== icon && iconPosition == "after" && (
              <span
                className={classnames(
                  `responsive-block-editor-addons-button__icon`,
                  `responsive-block-editor-addons-button__icon-position-${iconPosition}`
                )}
                style={{
                  marginLeft: iconSpace,
                }}
              >
                {renderSVG(icon)}
              </span>
            )}
          </div>
        </div>
      </Buttons>,
    ];
  }
}
