/**
 * Inspector Controls
 */

// Setup the block
const { __ } = wp.i18n;
const { Component } = wp.element;

// Import block components
const {
  InspectorControls,
  PanelColorSettings,
  AlignmentToolbar,
  BlockControls,
  InnerBlocks,
} = wp.editor;

// Import Inspector components
const { PanelBody, RangeControl, SelectControl, BaseControl } = wp.components;

/**
 * Create an Inspector Controls wrapper Component
 */
export default class Inspector extends Component {
  constructor(props) {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: { buttonAlignment, buttons, gap, stack },
      setAttributes,
    } = this.props;

    return (
      <InspectorControls key="inspector">
        <PanelBody
          title={__("General", "responsive-block-editor-addons")}
          initialOpen={true}
        >
          <BaseControl>
            <BaseControl.VisualLabel>
              {__("Alignment", "responsive-block-editor-addons")}
            </BaseControl.VisualLabel>
            <AlignmentToolbar
              value={buttonAlignment}
              onChange={(value) =>
                setAttributes({
                  buttonAlignment: value,
                })
              }
              controls={["left", "center", "right", "full"]}
              isCollapsed={false}
            />
          </BaseControl>
          <hr className="responsive-block-editor-addons-editor__separator" />
          <SelectControl
            label={__("Stack on")}
            value={stack}
            options={[
              { value: "none", label: __("None") },
              { value: "desktop", label: __("Desktop") },
              { value: "tablet", label: __("Tablet") },
              { value: "mobile", label: __("Mobile") },
            ]}
            onChange={(value) => setAttributes({ stack: value })}
            help={__(
              "Note: Choose breakpoint on which the buttons will stack."
            )}
          />
        </PanelBody>
      </InspectorControls>
    );
  }
}
