/**
 * BLOCK: Atomic Blocks Call-To-Action
 */

// Import block dependencies and components
import classnames from "classnames";
import Inspector from "./components/inspector";
import CallToAction from "./components/cta";
import Edit from "./components/edit";
import Save from "./components/save";

// Components
const { __ } = wp.i18n;

// Extend component
const { Component } = wp.element;

// Register block
const { registerBlockType } = wp.blocks;

// Register editor components
const {
  AlignmentToolbar,
  URLInput,
  BlockControls,
  BlockAlignmentToolbar,
  RichText,
} = wp.blockEditor;

// Register components
const { Button, Dashicon, Icon } = wp.components;

const blockAttributes = {
  buttonText: {
    type: "string",
  },
  buttonUrl: {
    type: "string",
    source: "attribute",
    selector: "a",
    attribute: "href",
  },
  buttonAlignment: {
    type: "string",
    default: "center",
  },
  buttonBackgroundColor: {
    type: "string",
    default: "#3373dc",
  },
  buttonTextColor: {
    type: "string",
    default: "#333333",
  },
  buttonSize: {
    type: "string",
    default: "responsive-block-editor-addons-cta-button-size-medium",
  },
  buttonShape: {
    type: "string",
    default: "responsive-block-editor-addons-cta-button-shape-rounded",
  },
  buttonTarget: {
    type: "boolean",
    default: false,
  },
  ctaTitle: {
    type: "array",
    selector: ".responsive-block-editor-addons-cta-title",
    source: "children",
  },
  ctaTitleFontSize: {
    type: "number",
    default: "22",
  },
  ctaTitleFontSizeMobile: {
    type: "number",
    default: "22",
  },
  ctaTitleFontSizeTablet: {
    type: "number",
    default: "22",
  },
  ctaTextFontSize: {
    type: "number",
    default: "16",
  },
  ctaText: {
    type: "array",
    selector: ".responsive-block-editor-addons-cta-text",
    source: "children",
  },
  ctaWidth: {
    type: "string",
  },
  ctaBackgroundColor: {
    type: "string",
  },
  ctaTextColor: {
    type: "string",
  },
  imgURL: {
    type: "string",
  },
  imgID: {
    type: "number",
  },
  imgAlt: {
    type: "string",
    source: "attribute",
    attribute: "alt",
    selector: "img",
  },
  dimRatio: {
    type: "number",
    default: 50,
  },
  opacity: {
    type: "number",
    default: 100,
  },
  headingLineHeight: {
    type: "number",
    default: 1.8,
  },
  headingFontWeight: {
    type: "string",
    default: "400",
  },
  contentLineHeight: {
    type: "number",
    default: 1.75,
  },
  contentFontWeight: {
    type: "string",
    default: "400",
  },
  buttonvPadding: {
    type: "number",
    default: 10,
  },
  buttonhPadding: {
    type: "number",
    default: 14,
  },
  buttonborderWidth: {
    type: "number",
    default: 1,
  },
  buttonborderStyle: {
    type: "string",
    default: "solid",
  },
  icon: {
    type: "string",
    default: "",
  },
  iconPosition: {
    type: "string",
    default: "after",
  },
  counterId: {
    type: "string",
    default: 1,
  },
  hbuttonBackgroundColor: {
    type: "string",
    default: "#3373dc",
  },
  hbuttonTextColor: {
    type: "string",
    default: "#333333",
  },
  buttonborderColor: {
    type: "string",
    default: "#3373dc",
  },
  buttonborderHColor: {
    type: "string",
    default: "#3373dc",
  },
  resctaType: {
    type: "string",
    default: "button",
  },
  ctalinkText: {
    type: "string",
  },
  titleSpace: {
    type: "number",
    default: 25,
  },
  subtitleSpace: {
    type: "number",
    default: 28,
  },
  iconSpace: {
    type: "number",
    default: 8,
  },
  colorLocation1: {
    type: "number",
    default: 0,
  },
  colorLocation2: {
    type: "number",
    default: 100,
  },
  gradientDirection: {
    type: "number",
    default: 90,
  },
  backgroundColor1: {
    type: "string",
  },
  backgroundColor2: {
    type: "string",
    default: "#fff",
  },
  backgroundType: {
    type: "string",
    default: "color",
  },
  buttoncolorLocation1: {
    type: "number",
    default: 0,
  },
  buttoncolorLocation2: {
    type: "number",
    default: 100,
  },
  buttongradientDirection: {
    type: "number",
    default: 90,
  },
  buttonbackgroundColor1: {
    type: "string",
  },
  buttonbackgroundColor2: {
    type: "string",
    default: "#fff",
  },
  buttonbackgroundType: {
    type: "string",
    default: "color",
  },
  boxShadowColor: {
    type: "string",
  },
  boxShadowHOffset: {
    type: "number",
    default: 0,
  },
  boxShadowVOffset: {
    type: "number",
    default: 0,
  },
  boxShadowBlur: {
    type: "number",
  },
  boxShadowSpread: {
    type: "number",
  },
  boxShadowPosition: {
    type: "string",
    default: "outset",
  },
  icon_color: {
    type: "string",
    default: "#3a3a3a",
  },
  topPadding: {
    type: "number",
    default: 20,
  },
  bottomPadding: {
    type: "number",
    default: 20,
  },
  leftPadding: {
    type: "number",
    default: 20,
  },
  rightPadding: {
    type: "number",
    default: 20,
  },
  imagePosition: {
    type: "string",
    default: "center center",
  },
  imageRepeat: {
    type: "string",
    default: "no-repeat",
  },
  thumbsize: {
    type: "string",
    default: "cover",
  },
  buttonSpace: {
    type: "number",
    default: 28,
  },
  borderRadius: {
    type: "number",
    default: 12,
  },
};

// Register the block
registerBlockType(
  "responsive-block-editor-addons/responsive-block-editor-addons-cta",
  {
    title: __("Call To Action", "responsive-block-editor-addons"),
    description: __(
      "Add a call to action section with a title, text, and a button.",
      "responsive-block-editor-addons"
    ),
    icon: "megaphone",
    category: "responsive_block_editor_addons",
    keywords: [
      __("call to action", "responsive-block-editor-addons"),
      __("cta", "responsive-block-editor-addons"),
      __("responsive", "responsive-block-editor-addons"),
    ],

    attributes: blockAttributes,

    responsive_block_editor_addons_settings_data: {
      responsive_block_editor_addons_cta_textOptions: {
        title: __("Text Options", "responsive-block-editor-addons"),
      },
      responsive_block_editor_addons_cta_backgroundOptions: {
        title: __("Background Options", "responsive-block-editor-addons"),
      },
      responsive_block_editor_addons_cta_buttonOptions: {
        title: __("Button Options", "responsive-block-editor-addons"),
      },
    },

    getEditWrapperProps({ ctaWidth }) {
      if ("left" === ctaWidth || "right" === ctaWidth || "full" === ctaWidth) {
        return { "data-align": ctaWidth };
      }
    },

    /* Render the block in the editor. */
    edit: (props) => {
      return <Edit {...props} />;
    },

    /* Save the block markup. */
    save: (props) => {
      return <Save {...props} />;
    },
  }
);
