/**
 * Internal dependencies
 */
import classnames from "classnames";
import Inspector from "./inspector";
import times from "lodash/times";
import renderSVG from "../../../renderIcon";
import ResponsiveBlocksIcon from "../../../ResponsiveBlocksIcon.json";
import React from "react";
import Style from "style-it";
import { hexToRgba } from "../../../utils/index.js";
import generateCSSUnit from "../../../generateCSSUnit";

/**
 * WordPress dependencies
 */
const { __, sprintf } = wp.i18n;
const { Component } = wp.element;
const { RichText, InnerBlocks, BlockControls, AlignmentToolbar } = wp.editor;
const { Button, Dashicon, Icon } = wp.components;
import memoize from "memize";
import map from "lodash/map";

const getCount = memoize((count) => {
  return times(count, (index) => [
    "responsive-block-editor-addons/count-up",
    {
      placeholder: sprintf(
        /* translators: %d: a digit 1-3 */
        __("Title %d", "responsive-block-editor-addons"),
        parseInt(index + 1)
      ),
    },
  ]);
});

let svg_icons = Object.keys(ResponsiveBlocksIcon);

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: {
        countUp,
        count,
        gutter,
        contentAlign,
        textColor,
        itemBackgroundColor,
        dateLineHeight,
        dateFontWeight,
        dateFontSize,
        headingLineHeight,
        titleFontWeight,
        headingFontSize,
        headingFontSizeMobile,
        headingFontSizeTablet,
        contentLineHeight,
        contentFontWeight,
        contentFontSize,
        icon,
        resshowIcon,
        resshowTitle,
        resshowDesc,
        blockBorderStyle,
        blockBorderWidth,
        blockBorderRadius,
        blockBorderColor,
        opacity,
        icon_color,
        counterId,
        iconsize,
        numColor,
        titleColor,
        titleSpace,
        numSpace,
        contentSpace,
        resshowNum,
        iconStyle,
        iconShapeColor,
        shapeBorderRadius,
        shapePadding,
        shapeBorder,
      },
      setAttributes,
    } = this.props;
    var data_copy = [...countUp];

    setAttributes({ counterId: this.props.clientId });

    const classes = classnames("responsive-count", {
      [`has-text-align-${contentAlign}`]: contentAlign,
    });

    const formattingControls = ["bold", "italic", "strikethrough"];

    let imgopacity = opacity / 100;

    return [
      // Show the alignment toolbar on focus
      <BlockControls key="controls">
        <AlignmentToolbar
          value={contentAlign}
          onChange={(value) => setAttributes({ contentAlign: value })}
        />
      </BlockControls>,

      // Show the block controls on focus

      <Inspector {...{ setAttributes, ...this.props }} />,
      <Style>
        {`
		  .responsive-block-editor-addons-countup-${counterId}.responsive-count__inner .responsive-count-item__features li {
			  line-height: ${contentLineHeight};
		  }
		  .responsive-block-editor-addons-countup-${counterId}.responsive-count__inner .responsive-block-editor-addons-count-up__source-wrap.res-countup-icon-design-shaped .responsive-block-editor-addons-count-up__source-icon {
			  background-color: ${iconShapeColor};
			  border-radius: ${generateCSSUnit(shapeBorderRadius, "px")};
			  padding: ${generateCSSUnit(shapePadding, "px")};
		  }
		  .responsive-block-editor-addons-countup-${counterId}.responsive-count__inner .responsive-block-editor-addons-count-up__source-wrap.res-countup-icon-design-outline .responsive-block-editor-addons-count-up__source-icon {
			  border-color: ${iconShapeColor};
			  border-radius: ${generateCSSUnit(shapeBorderRadius, "px")};
			  padding: ${generateCSSUnit(shapePadding, "px")};
			  border-width: ${generateCSSUnit(shapeBorder, "px")};
		  }
	  `}
      </Style>,
      <Style>
        {`
@media only screen and (min-width: 976px){
.responsive-block-editor-addons-countup-${counterId}.responsive-count__inner .responsive-count-item__title {
	font-size: ${headingFontSize}px ;
		}
}
@media only screen and (max-width: 976px){
.responsive-block-editor-addons-countup-${counterId}.responsive-count__inner .responsive-count-item__title {
	font-size: ${headingFontSizeTablet}px;
		}
}
@media only screen and (max-width: 767px){
	.responsive-block-editor-addons-countup-${counterId}.responsive-count__inner .responsive-count-item__title {
	font-size: ${headingFontSizeMobile}px;
		}
}
`}
      </Style>,
      <div className={classes}>
        {" "}
        <div
          className={classnames(
            `responsive-block-editor-addons-countup-${counterId}`,
            "responsive-count__inner"
          )}
        >
          {countUp.map((test, index) => (
            <div
              className={classnames("responsive-count-item")}
              style={{
                backgroundColor: `${hexToRgba(
                  itemBackgroundColor || "#ffffff",
                  imgopacity || 0
                )}`,
                borderWidth: blockBorderWidth,
                borderColor: blockBorderColor,
                borderStyle: blockBorderStyle,
                borderRadius: blockBorderRadius,
              }}
            >
              {resshowIcon && (
                <div
                  className={classnames(
                    "responsive-block-editor-addons-count-up__source-wrap",
                    `res-countup-icon-design-${iconStyle}`
                  )}
                >
                  <div className="responsive-block-editor-addons-count-up__source-icon">
                    <Dashicon
                      icon={countUp[index]["icon"]}
                      height={iconsize}
                      width={iconsize}
                      style={{
                        height: iconsize,
                        width: iconsize,
                        fill: icon_color,
                      }}
                    />
                  </div>
                </div>
              )}
              {resshowTitle && (
                <RichText
                  tagName="span"
                  className="responsive-count-item__title"
                  value={countUp[index]["title"]}
                  placeholder={countUp[index]["title"]}
                  onChange={(value) => {
                    var new_content = {
                      title: value,
                      amount: data_copy[index]["amount"],
                      features: data_copy[index]["features"],
                      icon: data_copy[index]["icon"],
                    };
                    data_copy[index] = new_content;
                    setAttributes({ countUp: data_copy });
                  }}
                  style={{
                    color: titleColor,
                    lineHeight: headingLineHeight,
                    fontWeight: titleFontWeight,
                    marginBottom: titleSpace,
                  }}
                  formattingControls={formattingControls}
                  keepPlaceholderOnFocus
                />
              )}
              {resshowNum && (
                <div className="responsive-count-item__price-wrapper">
                  <RichText
                    tagName="div"
                    className="responsive-count-item__amount"
                    style={{
                      color: numColor,
                      lineHeight: dateLineHeight,
                      fontWeight: dateFontWeight,
                      fontSize: dateFontSize,
                      marginBottom: numSpace,
                    }}
                    data-duration="1000"
                    data-delay="16"
                    placeholder={countUp[index]["amount"]}
                    value={countUp[index]["amount"]}
                    onChange={(value) => {
                      var new_content = {
                        title: data_copy[index]["title"],
                        amount: value,
                        features: data_copy[index]["features"],
                        icon: data_copy[index]["icon"],
                      };
                      data_copy[index] = new_content;
                      setAttributes({ countUp: data_copy });
                    }}
                    formattingControls={formattingControls}
                    keepPlaceholderOnFocus
                  />
                </div>
              )}
              {resshowDesc && (
                <RichText
                  tagName="ul"
                  multiline="li"
                  className="responsive-count-item__features"
                  value={countUp[index]["features"]}
                  placeholder={__(
                    "Description",
                    "responsive-block-editor-addons"
                  )}
                  onChange={(value) => {
                    var new_content = {
                      title: data_copy[index]["title"],
                      amount: data_copy[index]["amount"],
                      features: value,
                      icon: data_copy[index]["icon"],
                    };
                    data_copy[index] = new_content;
                    setAttributes({ countUp: data_copy });
                  }}
                  style={{
                    color: textColor,
                    lineHeight: contentLineHeight,
                    fontWeight: contentFontWeight,
                    fontSize: contentFontSize,
                    marginBottom: contentSpace,
                  }}
                  keepPlaceholderOnFocus
                />
              )}
            </div>
          ))}
        </div>
      </div>,
    ];
  }
}
