/**
 * Internal dependencies
 */
import classnames from "classnames";
import Inspector from "./inspector";
import IconList from "./iconlist";
import memoize from "memize";
import times from "lodash/times";
import React from "react";
import Style from "style-it";
import generateCSSUnit from "../../../generateCSSUnit";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { select } = wp.data;
const { Component, Fragment } = wp.element;
const {
  RichText,
  AlignmentToolbar,
  BlockControls,
  InnerBlocks,
  InspectorControls,
} = wp.editor;
const {
  Button,
  Dashicon,
  BaseControl,
  PanelBody,
  RangeControl,
} = wp.components;

const ALLOWED_BLOCKS = ["responsive-block-editor-addons/icons-list-child"];

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  componentDidMount() {
    // Pushing Style tag for this block css.
    const $style = document.createElement("style");
    $style.setAttribute(
      "id",
      "responsive-block-editor-addons-style-icon-list-" + this.props.clientId
    );
    document.head.appendChild($style);

    this.changeChildAttr(this.props.attributes.hideLabel);
  }

  changeChildAttr(value) {
    const { setAttributes } = this.props;
    const getChildBlocks = select("core/block-editor").getBlocks(
      this.props.clientId
    );

    getChildBlocks.forEach((iconChild, key) => {
      iconChild.attributes.hideLabel = value;
    });
    setAttributes({ hideLabel: value });
  }

  render() {
    // Setup the attributes
    const { attributes, setAttributes } = this.props;

    const {
      align,
      icon_count,
      icons,
      hideLabel,
      gap,
      inner_gap,
      size,
      fontSize,
      border,
      bgSize,
      borderRadius,
      fontSizeType,
      maincounterId,
    } = attributes;

    setAttributes({ maincounterId: this.props.clientId });

    const getIconTemplate = memoize((icon_block, icons) => {
      return times(icon_block, (n) => [
        "responsive-block-editor-addons/icons-list-child",
        icons[n],
      ]);
    });

    var element = document.getElementById(
      "responsive-block-editor-addons-style-icon-list-" + this.props.clientId
    );

    const labelClass = hideLabel
      ? "responsive-block-editor-addons-icon-list__no-label"
      : "";

    var editor_gap = undefined !== typeof gap && "" !== gap ? gap + 15 : 15;

    var alignment =
      align == "left" ? "flex-start" : align == "right" ? "flex-end" : "center";

    return (
      <Fragment>
        <BlockControls key="controls">
          <AlignmentToolbar
            value={align}
            onChange={(value) => setAttributes({ align: value })}
          />
        </BlockControls>

        <Inspector {...{ setAttributes, ...this.props }} />

        <Style>
          {`
		  .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-icon svg {
		   width: ${generateCSSUnit(size, fontSizeType)};
		   height: ${generateCSSUnit(size, fontSizeType)};
	   }

	   .responsive-block-editor-addons-icon-list__layout-horizontal .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__content-wrap {
		   margin-left: ${generateCSSUnit(editor_gap / 2, "px")};
		   margin-right: ${generateCSSUnit(editor_gap / 2, "px")};
	   }

	   .responsive-block-editor-addons-icon-list__layout-vertical .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__content-wrap {
		   margin-bottom: ${generateCSSUnit(editor_gap, "px")};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-wrap {
		   padding: ${generateCSSUnit(bgSize, "px")};
		   border-radius: ${generateCSSUnit(borderRadius, "px")};
		   border-width: ${generateCSSUnit(border, "px")};
		   margin-right: ${generateCSSUnit(inner_gap, "px")};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-icon {
		   width: ${generateCSSUnit(size, fontSizeType)};
		   height: ${generateCSSUnit(size, fontSizeType)};
		   font-size: ${generateCSSUnit(size, fontSizeType)};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-image {
		   width: ${generateCSSUnit(size, fontSizeType)};
		   height: ${generateCSSUnit(size, fontSizeType)};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__label-wrap {
		   text-align: ${align};
	   }
	   .responsive-block-editor-addons-icon-wrap-${maincounterId}.responsive-block-editor-addons-icon-list__wrap .block-editor-inner-blocks {
		   text-align: ${align};
	   }

	   .responsive-block-editor-addons-icon-list__layout-horizontal .responsive-block-editor-addons-icon-wrap-${maincounterId} .block-editor-block-list__layout {
		   justify-content: ${alignment};
		   -webkit-box-pack: ${alignment};
		   -ms-flex-pack: ${alignment};
	   }

	   .responsive-block-editor-addons-icon-list__layout-horizontal .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__content-wrap:first-child {
 		  margin-left: 0;
 	  }

	`}
        </Style>

        <IconList {...this.props}>
          <div
            className={classnames(
              `responsive-block-editor-addons-icon-wrap-${maincounterId}`,
              "responsive-block-editor-addons-icon-list__wrap"
            )}
          >
            <InnerBlocks
              template={getIconTemplate(icon_count, icons)}
              templateLock={false}
              allowedBlocks={ALLOWED_BLOCKS}
            />
          </div>
        </IconList>
      </Fragment>
    );
  }
}
