/**
 * Internal dependencies
 */
import IconList from "./iconlist";
import classnames from "classnames";
import React from "react";
import Style from "style-it";
import generateCSSUnit from "../../../generateCSSUnit";

/**
 * WordPress dependencies
 */
const { Component } = wp.element;
const { InnerBlocks } = wp.editor;

export default class Save extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      align,
      icon_count,
      icons,
      hideLabel,
      gap,
      inner_gap,
      size,
      fontSize,
      border,
      bgSize,
      borderRadius,
      fontSizeType,
      maincounterId,
    } = this.props.attributes;

    const labelClass = hideLabel
      ? "responsive-block-editor-addons-icon-list__no-label"
      : "";

    var editor_gap = undefined !== typeof gap && "" !== gap ? gap + 15 : 15;
    var alignment =
      align == "left" ? "flex-start" : align == "right" ? "flex-end" : "center";

    return [
      <Style type="text/css">
        {`
		  .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-icon svg {
		   width: ${generateCSSUnit(size, fontSizeType)};
		   height: ${generateCSSUnit(size, fontSizeType)};
	   }

	   .responsive-block-editor-addons-icon-list__layout-horizontal .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__content-wrap {
		   margin-left: ${generateCSSUnit(editor_gap / 2, "px")};
		   margin-right: ${generateCSSUnit(editor_gap / 2, "px")};
	   }

	   .responsive-block-editor-addons-icon-list__layout-vertical .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__content-wrap {
		   margin-bottom: ${generateCSSUnit(editor_gap, "px")};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-wrap {
		   padding: ${generateCSSUnit(bgSize, "px")};
		   border-radius: ${generateCSSUnit(borderRadius, "px")};
		   border-width: ${generateCSSUnit(border, "px")};
		   margin-right: ${generateCSSUnit(inner_gap, "px")};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-icon {
		   width: ${generateCSSUnit(size, fontSizeType)};
		   height: ${generateCSSUnit(size, fontSizeType)};
		   font-size: ${generateCSSUnit(size, fontSizeType)};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__source-image {
		   width: ${generateCSSUnit(size, fontSizeType)};
		   height: ${generateCSSUnit(size, fontSizeType)};
	   }

	   .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__label-wrap {
		   text-align: ${align};
	   }

	  .responsive-block-editor-addons-icon-list__outer-wrap .responsive-block-editor-addons-icon-wrap-${maincounterId}.responsive-block-editor-addons-icon-list__wrap {
		  align-items: ${alignment};
		  align-items: ${align};
		  justify-content: ${align};
		  justify-content: ${alignment};
	  }

	  .responsive-block-editor-addons-icon-list__layout-horizontal .responsive-block-editor-addons-icon-wrap-${maincounterId} .block-editor-block-list__layout {
		  justify-content: ${alignment};
		  -webkit-box-pack: ${alignment};
		  -ms-flex-pack: ${alignment};
	  }

	  .responsive-block-editor-addons-icon-list__layout-horizontal .responsive-block-editor-addons-icon-wrap-${maincounterId} .responsive-block-editor-addons-icon-list__content-wrap:first-child {
		  margin-left: 0;
	  }

  	`}
      </Style>,
      <IconList {...this.props}>
        <div
          className={classnames(
            `responsive-block-editor-addons-icon-wrap-${maincounterId}`,
            "responsive-block-editor-addons-icon-list__wrap"
          )}
        >
          <InnerBlocks.Content />
        </div>
      </IconList>,
    ];
  }
}
