/**
 * Internal dependencies
 */
import classnames from "classnames";
import Inspector from "./inspector";
import IconList from "./iconlist";
import renderSVG from "../../../../renderIcon";
import ResponsiveBlocksIcon from "../../../../ResponsiveBlocksIcon.json";
import React from "react";
import Style from "style-it";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const {
  RichText,
  AlignmentToolbar,
  BlockControls,
  InnerBlocks,
  InspectorControls,
} = wp.editor;
const {
  Button,
  Dashicon,
  BaseControl,
  PanelBody,
  RangeControl,
} = wp.components;

const ALLOWED_BLOCKS = ["responsive-block-editor-addons/icons-list"];

let svg_icons = Object.keys(ResponsiveBlocksIcon);

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  componentDidMount() {
    // Assigning block_id in the attribute.
    this.props.setAttributes({ block_id: this.props.clientId });

    // Pushing Style tag for this block css.
    const $style = document.createElement("style");
    $style.setAttribute(
      "id",
      "responsive-block-editor-addons-style-icon-list-child-" +
        this.props.clientId
    );
    document.head.appendChild($style);
  }

  render() {
    // Setup the attributes
    const { attributes, setAttributes } = this.props;

    const {
      label,
      hideLabel,
      icon,
      align,
      gap,
      inner_gap,
      icon_layout,
      size,
      fontSize,
      border,
      bgSize,
      borderRadius,
      fontSizeType,
      icon_color,
      label_color,
      icon_hover_color,
      label_hover_color,
      icon_bg_color,
      icon_bg_hover_color,
      icon_border_color,
      icon_border_hover_color,
      counterId,
      image,
      source_type,
      link,
      target,
      disableLink,
    } = attributes;

    setAttributes({ counterId: this.props.clientId });

    let image_icon_html = "";

    if (source_type == "icon") {
      if (icon) {
        image_icon_html = (
          <span className="responsive-block-editor-addons-icon-list__source-icon">
            {renderSVG(icon)}
          </span>
        );
      }
    } else {
      if (image && image.url) {
        image_icon_html = (
          <img
            className="responsive-block-editor-addons-icon-list__source-image"
            src={image.url}
          />
        );
      }
    }

    let target_val = target ? "_blank" : "_self";
    let link_url = !disableLink ? link : "/";

    var element = document.getElementById(
      "responsive-block-editor-addons-style-icon-list-child-" +
        this.props.clientId
    );

    return (
      <Fragment>
        <Inspector {...{ setAttributes, ...this.props }} />

        <Style>
          {`
		  .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__source-icon {
			  color: ${icon_color};
		  }
		  .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__source-icon:hover {
			  color: ${icon_hover_color};
		  }

		  .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__source-wrap {
			  background-color: ${icon_bg_color};
 			 border-color: ${icon_border_color};
		 }
		 .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__source-wrap:hover {
			 background-color: ${icon_bg_hover_color};
			 border-color: ${icon_border_hover_color};
		 }

		  .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__source-icon svg {
			  fill: ${icon_color};
		  }
		  .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__source-icon svg:hover {
			  fill: ${icon_hover_color};
		  }

		  .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__label {
			 color: ${label_color};
		 }
		 .responsive-block-editor-addons-icon-${counterId}.responsive-block-editor-addons-icon-list__content-wrap .responsive-block-editor-addons-icon-list__label:hover {
			 color: ${label_hover_color};
		 }
	  `}
        </Style>

        <IconList {...this.props}>
          {!disableLink && (
            <a
              target={target_val}
              rel="noopener noreferrer"
              aria-label={label}
              href={link_url}
              class="responsive-block-editor-addons-icon-list-link"
            ></a>
          )}
          <div
            className={classnames(
              `responsive-block-editor-addons-icon-${counterId}`,
              " responsive-block-editor-addons-icon-list__content-wrap"
            )}
          >
            <span className="responsive-block-editor-addons-icon-list__source-wrap">
              {image_icon_html}
            </span>
            {!hideLabel && (
              <div className="responsive-block-editor-addons-icon-list__label-wrap">
                <RichText
                  tagName="div"
                  placeholder={__(
                    "Label Name",
                    "responsive-block-editor-addons"
                  )}
                  value={label}
                  onChange={(value) => setAttributes({ label: value })}
                  className="responsive-block-editor-addons-icon-list__label"
                  multiline={false}
                  allowedFormats={[
                    "core/bold",
                    "core/italic",
                    "core/strikethrough",
                  ]}
                />
              </div>
            )}
          </div>
        </IconList>
      </Fragment>
    );
  }
}
