/**
 * Internal dependencies
 */
import classnames from "classnames";
import icons from "./../../../utils/components/icons";
import renderSVG from "../../../renderIcon";
import Inspector from "./inspector";
import InfoBlock from "./infoblock";
import ResponsiveBlocksIcon from "../../../ResponsiveBlocksIcon.json";
import InfoBoxPositionClasses from "./classes";
import generateCSSUnit from "../../../generateCSSUnit";
import React from "react";
import Style from "style-it";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const {
  RichText,
  AlignmentToolbar,
  BlockControls,
  MediaUpload,
  InnerBlocks,
  MediaUploadCheck,
  figure,
  URLInput,
} = wp.editor;
const { Button, Dashicon, Icon } = wp.components;

let svg_icons = Object.keys(ResponsiveBlocksIcon);

export default class Edit extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: {
        resinfoBlockTitle,
        resDescHeading,
        resheadingAlign,
        resheadingColor,
        ressubheadingColor,
        resprefixTitle,
        resprefixColor,
        resprefixFontSize,
        resprefixFontWeight,
        resprefixLineHeight,
        resheadingTag,
        resheadFontSize,
        resheadFontSizeTablet,
        resheadFontSizeMobile,
        resheadFontWeight,
        resheadLineHeight,
        ressubHeadFontSize,
        ressubHeadFontWeight,
        ressubHeadLineHeight,
        resseparatorWidthType,
        resseperatorSpace,
        resheadSpace,
        ressubHeadSpace,
        icon,
        iconColor,
        resIconSize,
        imgiconPosition,
        resiconimgBorderRadius,
        source_type,
        ressourceAlign,
        resseperatorPosition,
        resseperatorStyle,
        resseperatorWidth,
        resseperatorColor,
        resseperatorThickness,
        resctaType,
        resctaText,
        resctaLink,
        resctaTarget,
        ctaIcon,
        resctaLinkColor,
        resctaFontSize,
        resctaFontWeight,
        resctaBtnLinkColor,
        resctaBgColor,
        ctaBtnVertPadding,
        ctaBtnHrPadding,
        resctaBorderStyle,
        resctaBorderColor,
        resctaBorderWidth,
        resctaBorderRadius,
        resprefixSpace,
        iconLeftMargin,
        iconRightMargin,
        iconTopMargin,
        iconBottomMargin,
        iconImage,
        imageSize,
        imageWidth,
        imageWidthType,
        stack,
        resshowPrefix,
        resshowTitle,
        resshowDesc,
        inheritFromTheme,
        blockBorderStyle,
        blockBorderWidth,
        blockBorderRadius,
        blockBorderColor,
        boxShadowColor,
        boxShadowHOffset,
        boxShadowVOffset,
        boxShadowBlur,
        boxShadowSpread,
        boxShadowPosition,
        counterId,
        opacity,
        imgURL,
        imgAlt,
        dimRatio,
        hoverctaBtnLinkColor,
        hoverctaBgColor,
        hoverctaBorderColor,
        imagePosition,
        imageRepeat,
        thumbsize,
        backgroundAttachment,
        sepSpace,
      },
      setAttributes,
    } = this.props;

    setAttributes({ counterId: this.props.clientId });

    const onSelectBgImage = (img) => {
      setAttributes({
        imgID: img.id,
        imgURL: img.url,
        imgAlt: img.alt,
      });
    };

    const dimRatioToClass = (ratio) => {
      return 0 === ratio || 50 === ratio
        ? null
        : "has-background-dim-" + 10 * Math.round(ratio / 10);
    };

    let ctaBtnClass =
      "responsive-block-editor-addons-infobox-cta-link responsive-block-editor-addons-ifb-cta-button";

    let target = "_self";
    let rel = "noopener noreferrer";
    if (resctaTarget) {
      target = "_blank";
    }

    let url_chk = "";
    if (
      typeof iconImage !== "undefined" &&
      iconImage !== null &&
      iconImage !== ""
    ) {
      url_chk = iconImage.url;
    }

    let url = "";
    if (url_chk !== "") {
      let size = iconImage.sizes;
      let imageSize = imageSize;

      if (
        typeof size !== "undefined" &&
        typeof size[imageSize] !== "undefined"
      ) {
        url = size[imageSize].url;
      } else {
        url = url_chk;
      }
    } else {
      <div className="responsive-block-editor-addons-ifb-image-content"></div>;
    }

    // Get icon/Image components.
    let is_image = "";
    if (source_type === "icon" && icon !== "") {
      is_image = (
        <div
          className="responsive-block-editor-addons-ifb-image-icon-content responsive-block-editor-addons-ifb-imgicon-wrap"
          style={{
            marginBottom: iconBottomMargin,
            marginTop: iconTopMargin,
            marginLeft: iconLeftMargin,
            marginRight: iconRightMargin,
          }}
        >
          <div className="responsive-block-editor-addons-ifb-icon-wrap">
            <span
              className="responsive-block-editor-addons-ifb-icon"
              style={{
                width: resIconSize,
                height: resIconSize,
              }}
            >
              {renderSVG(icon)}
            </span>
          </div>
        </div>
      );
    } else {
      is_image = (
        <div
          className="responsive-block-editor-addons-ifb-image-icon-content responsive-block-editor-addons-ifb-imgicon-wrap"
          style={{
            marginBottom: iconBottomMargin,
            marginTop: iconTopMargin,
            marginLeft: iconLeftMargin,
            marginRight: iconRightMargin,
          }}
        >
          <div className="responsive-block-editor-addons-ifb-image">
            <div className="responsive-block-editor-addons-ifb-image-content">
              <img
                className=""
                src={url}
                alt=""
                style={{
                  borderRadius: resiconimgBorderRadius,
                  width: imageWidth,
                  maxWidth: imageWidth,
                }}
              />
            </div>
          </div>
        </div>
      );
    }
    var icon_image_html = is_image;
    var seperator_position = resseperatorPosition;
    var seperator_html = (
      <div className="responsive-block-editor-addons-ifb-separator-parent">
        <div
          className="responsive-block-editor-addons-ifb-separator"
          style={{
            borderWidth: resseperatorThickness,
            borderColor: resseperatorColor,
            borderStyle: resseperatorStyle,
            width: generateCSSUnit(resseperatorWidth, resseparatorWidthType),
            marginBottom: sepSpace,
          }}
        ></div>
      </div>
    );
    var show_seperator = true;

    if (
      resseperatorPosition == "after_icon" &&
      (imgiconPosition == "above-title" || imgiconPosition == "below-title")
    ) {
      show_seperator = false;
      icon_image_html = (
        <Fragment>
          {is_image}
          {"none" !== resseperatorStyle && seperator_html}
        </Fragment>
      );
    }

    if (
      resseperatorPosition == "after_icon" &&
      (imgiconPosition !== "above-title" || imgiconPosition !== "below-title")
    ) {
      seperator_position = "after_title";
    }

    if (
      imgiconPosition == "below-title" &&
      resseperatorPosition == "after_title"
    ) {
      show_seperator = false;
      icon_image_html = (
        <Fragment>
          {"none" !== resseperatorStyle && seperator_html}
          {is_image}
        </Fragment>
      );
    }

    return [
      <Fragment>
        {(imgiconPosition == "above-title" ||
          imgiconPosition == "below-title") && (
          <BlockControls key="controls">
            <AlignmentToolbar
              value={resheadingAlign}
              onChange={(value) => setAttributes({ resheadingAlign: value })}
            />
          </BlockControls>
        )}
        <Inspector {...{ setAttributes, ...this.props }} />

        <Style>
          {`
	  .responsive-block-editor-addons-block-${counterId} .responsive-block-editor-addons-ifb-cta-button {
		  background-color: ${resctaBgColor};
		  border-color: ${resctaBorderColor};
	  }
	  .responsive-block-editor-addons-block-${counterId} .responsive-block-editor-addons-ifb-cta-button .responsive-block-editor-addons-inline-editing{
		  color: ${resctaBtnLinkColor};
	  }
	  .responsive-block-editor-addons-block-${counterId} .responsive-block-editor-addons-ifb-cta-button:hover {
		  background-color: ${hoverctaBgColor};
		  border-color: ${hoverctaBorderColor};
	  }

	  .responsive-block-editor-addons-block-${counterId} .responsive-block-editor-addons-ifb-cta-button .responsive-block-editor-addons-inline-editing:hover{
		  color: ${hoverctaBtnLinkColor};
	  }
  `}
        </Style>

        {(imgiconPosition == "above-title" ||
          imgiconPosition == "below-title") && (
          <Style>
            {`
		  .responsive-block-editor-addons-block-${counterId}.responsive-block-editor-addons-infobox__content-wrap {
			  text-align: ${resheadingAlign};
		  }
	  `}
          </Style>
        )}
        <Style>
          {`
@media only screen and (min-width: 976px){
.responsive-block-editor-addons-block-${counterId}.responsive-block-editor-addons-infobox__content-wrap .responsive-block-editor-addons-ifb-title {
	font-size: ${resheadFontSize}px !important;
		}
}
@media only screen and (max-width: 976px){
.responsive-block-editor-addons-block-${counterId}.responsive-block-editor-addons-infobox__content-wrap .responsive-block-editor-addons-ifb-title {
	font-size: ${resheadFontSizeTablet}px;
		}
}
@media only screen and (max-width: 767px){
	.responsive-block-editor-addons-block-${counterId}.responsive-block-editor-addons-infobox__content-wrap .responsive-block-editor-addons-ifb-title {
	font-size: ${resheadFontSizeMobile}px;
		}
}
`}
        </Style>
        <InfoBlock {...this.props}>
          <div
            className={classnames(
              `responsive-block-editor-addons-block-${counterId}`,
              "responsive-block-editor-addons-infobox__content-wrap",
              ...InfoBoxPositionClasses(this.props.attributes)
            )}
          >
            {imgURL && !!imgURL.length && (
              <div className="responsive-block-editor-addons-cta-image-wrap">
                <img
                  className={classnames(
                    "responsive-block-editor-addons-cta-image",
                    dimRatioToClass(dimRatio),
                    {
                      "has-background-dim": 0 !== dimRatio,
                    }
                  )}
                  style={{
                    backgroundImage: `url(${imgURL})`,
                    backgroundPosition: imagePosition,
                    backgroundRepeat: imageRepeat,
                    backgroundSize: thumbsize,
                    backgroundAttachment: backgroundAttachment,
                  }}
                />
              </div>
            )}
            <div className="responsive-block-editor-addons-ifb-left-right-wrap">
              {imgiconPosition == "left" && icon_image_html}
              <div className="responsive-block-editor-addons-ifb-content">
                {imgiconPosition == "above-title" && icon_image_html}

                {(imgiconPosition == "above-title" ||
                  imgiconPosition == "below-title") && (
                  <div className="responsive-block-editor-addons-ifb-title-wrap">
                    {resshowPrefix && (
                      <RichText
                        tagName="div"
                        value={resprefixTitle}
                        placeholder={__(
                          "Write a Prefix",
                          "responsive-block-editor-addons"
                        )}
                        className="responsive-block-editor-addons-ifb-title-prefix"
                        multiline={false}
                        onChange={(value) => {
                          setAttributes({ resprefixTitle: value });
                        }}
                        style={{
                          color: resprefixColor,
                          fontSize: resprefixFontSize,
                          fontWeight: resprefixFontWeight,
                          lineHeight: resprefixLineHeight,
                          marginBottom: resprefixSpace,
                        }}
                      />
                    )}
                    {"none" !== resseperatorStyle &&
                      seperator_position == "after_prefix" &&
                      seperator_html}
                    {resshowTitle && (
                      <RichText
                        tagName={resheadingTag}
                        placeholder={__(
                          "Write a Heading",
                          "responsive-block-editor-addons"
                        )}
                        value={resinfoBlockTitle}
                        className="responsive-block-editor-addons-ifb-title"
                        onChange={(value) =>
                          setAttributes({ resinfoBlockTitle: value })
                        }
                        multiline={false}
                        style={{
                          color: resheadingColor,
                          fontWeight: resheadFontWeight,
                          lineHeight: resheadLineHeight,
                          marginBottom: resheadSpace,
                        }}
                      />
                    )}
                  </div>
                )}

                {imgiconPosition == "below-title" && icon_image_html}

                {(imgiconPosition == "above-title" ||
                  imgiconPosition == "below-title") && (
                  <Fragment>
                    {"none" !== resseperatorStyle &&
                      seperator_position == "after_title" &&
                      show_seperator &&
                      seperator_html}
                    <div className="responsive-block-editor-addons-ifb-text-wrap">
                      {resshowDesc && (
                        <RichText
                          tagName="p"
                          value={resDescHeading}
                          placeholder={__(
                            "Write a Description",
                            "responsive-block-editor-addons"
                          )}
                          className="responsive-block-editor-addons-ifb-desc"
                          value={resDescHeading}
                          style={{
                            color: ressubheadingColor,
                            fontSize: ressubHeadFontSize,
                            fontWeight: ressubHeadFontWeight,
                            lineHeight: ressubHeadLineHeight,
                            marginBottom: ressubHeadSpace,
                          }}
                          onChange={(value) =>
                            setAttributes({ resDescHeading: value })
                          }
                        />
                      )}
                      {"none" !== resseperatorStyle &&
                        seperator_position == "after_desc" &&
                        seperator_html}
                      <div className="responsive-block-editor-addons-ifb-cta responsive-block-editor-addons-infobox-cta-link-style">
                        {resctaType === "text" && (
                          <a
                            target={target}
                            className="responsive-block-editor-addons-infobox-cta-link"
                            rel={rel}
                            style={{
                              color: resctaLinkColor,
                              paddingTop: ctaBtnVertPadding,
                              paddingBottom: ctaBtnVertPadding,
                              paddingLeft: ctaBtnHrPadding,
                              paddingRight: ctaBtnHrPadding,
                              fontSize: resctaFontSize,
                              fontWeight: resctaFontWeight,
                            }}
                          >
                            <span
                              className="responsive-block-editor-addons-inline-editing"
                              style={{
                                color: resctaLinkColor,
                                fontSize: resctaFontSize,
                              }}
                            >
                              {resctaText}
                            </span>
                          </a>
                        )}

                        {resctaType === "button" && (
                          <div
                            className={classnames(
                              "responsive-block-editor-addons-ifb-button-wrapper"
                            )}
                          >
                            <a
                              className={ctaBtnClass}
                              target={target}
                              rel={rel}
                              style={{
                                borderWidth: resctaBorderWidth,
                                borderStyle: resctaBorderStyle,
                                borderRadius: resctaBorderRadius,
                                paddingTop: ctaBtnVertPadding,
                                paddingBottom: ctaBtnVertPadding,
                                paddingLeft: ctaBtnHrPadding,
                                paddingRight: ctaBtnHrPadding,
                                fontSize: resctaFontSize,
                                fontWeight: resctaFontWeight,
                              }}
                            >
                              <span className="responsive-block-editor-addons-ifb-cta-content-wrapper">
                                <span
                                  className="responsive-block-editor-addons-inline-editing "
                                  style={{
                                    fontSize: resctaFontSize,
                                  }}
                                >
                                  {resctaText}
                                </span>
                              </span>
                            </a>
                          </div>
                        )}
                      </div>
                    </div>
                  </Fragment>
                )}

                {imgiconPosition === "left-title" && (
                  <Fragment>
                    <div className="responsive-block-editor-addons-ifb-left-title-image">
                      {icon_image_html}
                      <div className="responsive-block-editor-addons-ifb-title-wrap">
                        {resshowPrefix && (
                          <RichText
                            tagName="div"
                            value={resprefixTitle}
                            placeholder={__(
                              "Write a Prefix",
                              "responsive-block-editor-addons"
                            )}
                            className="responsive-block-editor-addons-ifb-title-prefix"
                            multiline={false}
                            onChange={(value) => {
                              setAttributes({ resprefixTitle: value });
                            }}
                            style={{
                              color: resprefixColor,
                              fontSize: resprefixFontSize,
                              fontWeight: resprefixFontWeight,
                              lineHeight: resprefixLineHeight,
                              marginBottom: resprefixSpace,
                            }}
                          />
                        )}
                        {"none" !== resseperatorStyle &&
                          seperator_position == "after_prefix" &&
                          seperator_html}
                        {resshowTitle && (
                          <RichText
                            tagName={resheadingTag}
                            placeholder={__(
                              "Write a Heading",
                              "responsive-block-editor-addons"
                            )}
                            value={resinfoBlockTitle}
                            className="responsive-block-editor-addons-ifb-title"
                            onChange={(value) =>
                              setAttributes({ resinfoBlockTitle: value })
                            }
                            multiline={false}
                            style={{
                              color: resheadingColor,
                              fontWeight: resheadFontWeight,
                              lineHeight: resheadLineHeight,
                              marginBottom: resheadSpace,
                            }}
                          />
                        )}
                      </div>
                    </div>
                    {"none" !== resseperatorStyle &&
                      seperator_position == "after_title" &&
                      show_seperator &&
                      seperator_html}
                    <div className="responsive-block-editor-addons-ifb-text-wrap">
                      {resshowDesc && (
                        <RichText
                          tagName="p"
                          value={resDescHeading}
                          placeholder={__(
                            "Write a Description",
                            "responsive-block-editor-addons"
                          )}
                          className="responsive-block-editor-addons-ifb-desc"
                          value={resDescHeading}
                          style={{
                            color: ressubheadingColor,
                            fontSize: ressubHeadFontSize,
                            fontWeight: ressubHeadFontWeight,
                            lineHeight: ressubHeadLineHeight,
                            marginBottom: ressubHeadSpace,
                          }}
                          onChange={(value) =>
                            setAttributes({ resDescHeading: value })
                          }
                        />
                      )}
                      {"none" !== resseperatorStyle &&
                        seperator_position == "after_desc" &&
                        seperator_html}
                      <div className="responsive-block-editor-addons-ifb-cta responsive-block-editor-addons-infobox-cta-link-style">
                        {resctaType === "text" && (
                          <a
                            target={target}
                            className="responsive-block-editor-addons-infobox-cta-link"
                            rel={rel}
                            style={{
                              color: resctaLinkColor,
                              paddingTop: ctaBtnVertPadding,
                              paddingBottom: ctaBtnVertPadding,
                              paddingLeft: ctaBtnHrPadding,
                              paddingRight: ctaBtnHrPadding,
                              fontSize: resctaFontSize,
                              fontWeight: resctaFontWeight,
                            }}
                          >
                            <span
                              className="responsive-block-editor-addons-inline-editing"
                              style={{
                                color: resctaLinkColor,
                                fontSize: resctaFontSize,
                              }}
                            >
                              {resctaText}
                            </span>
                          </a>
                        )}

                        {resctaType === "button" && (
                          <div
                            className={classnames(
                              "responsive-block-editor-addons-ifb-button-wrapper"
                            )}
                          >
                            <a
                              className={ctaBtnClass}
                              target={target}
                              rel={rel}
                              style={{
                                borderWidth: resctaBorderWidth,
                                borderStyle: resctaBorderStyle,
                                borderRadius: resctaBorderRadius,
                                paddingTop: ctaBtnVertPadding,
                                paddingBottom: ctaBtnVertPadding,
                                paddingLeft: ctaBtnHrPadding,
                                paddingRight: ctaBtnHrPadding,
                                fontSize: resctaFontSize,
                                fontWeight: resctaFontWeight,
                              }}
                            >
                              <span className="responsive-block-editor-addons-ifb-cta-content-wrapper">
                                <span
                                  className="responsive-block-editor-addons-inline-editing "
                                  style={{
                                    fontSize: resctaFontSize,
                                  }}
                                >
                                  {resctaText}
                                </span>
                              </span>
                            </a>
                          </div>
                        )}
                      </div>
                    </div>
                  </Fragment>
                )}

                {imgiconPosition === "right-title" && (
                  <Fragment>
                    <div className="responsive-block-editor-addons-ifb-right-title-image">
                      <div className="responsive-block-editor-addons-ifb-title-wrap">
                        {resshowPrefix && (
                          <RichText
                            tagName="div"
                            value={resprefixTitle}
                            placeholder={__(
                              "Write a Prefix",
                              "responsive-block-editor-addons"
                            )}
                            className="responsive-block-editor-addons-ifb-title-prefix"
                            multiline={false}
                            onChange={(value) => {
                              setAttributes({ resprefixTitle: value });
                            }}
                            style={{
                              color: resprefixColor,
                              fontSize: resprefixFontSize,
                              fontWeight: resprefixFontWeight,
                              lineHeight: resprefixLineHeight,
                              marginBottom: resprefixSpace,
                            }}
                          />
                        )}
                        {"none" !== resseperatorStyle &&
                          seperator_position == "after_prefix" &&
                          seperator_html}
                        {resshowTitle && (
                          <RichText
                            tagName={resheadingTag}
                            placeholder={__(
                              "Write a Heading",
                              "responsive-block-editor-addons"
                            )}
                            value={resinfoBlockTitle}
                            className="responsive-block-editor-addons-ifb-title"
                            onChange={(value) =>
                              setAttributes({ resinfoBlockTitle: value })
                            }
                            multiline={false}
                            style={{
                              color: resheadingColor,
                              fontWeight: resheadFontWeight,
                              lineHeight: resheadLineHeight,
                              marginBottom: resheadSpace,
                            }}
                          />
                        )}
                      </div>
                      {icon_image_html}
                    </div>
                    {"none" !== resseperatorStyle &&
                      seperator_position == "after_title" &&
                      show_seperator &&
                      seperator_html}
                    <div className="responsive-block-editor-addons-ifb-text-wrap">
                      {resshowDesc && (
                        <RichText
                          tagName="p"
                          value={resDescHeading}
                          placeholder={__(
                            "Write a Description",
                            "responsive-block-editor-addons"
                          )}
                          className="responsive-block-editor-addons-ifb-desc"
                          value={resDescHeading}
                          style={{
                            color: ressubheadingColor,
                            fontSize: ressubHeadFontSize,
                            fontWeight: ressubHeadFontWeight,
                            lineHeight: ressubHeadLineHeight,
                            marginBottom: ressubHeadSpace,
                          }}
                          onChange={(value) =>
                            setAttributes({ resDescHeading: value })
                          }
                        />
                      )}
                      {"none" !== resseperatorStyle &&
                        seperator_position == "after_desc" &&
                        seperator_html}
                      <div className="responsive-block-editor-addons-ifb-cta responsive-block-editor-addons-infobox-cta-link-style">
                        {resctaType === "text" && (
                          <a
                            target={target}
                            className="responsive-block-editor-addons-infobox-cta-link"
                            rel={rel}
                            style={{
                              color: resctaLinkColor,
                              paddingTop: ctaBtnVertPadding,
                              paddingBottom: ctaBtnVertPadding,
                              paddingLeft: ctaBtnHrPadding,
                              paddingRight: ctaBtnHrPadding,
                              fontSize: resctaFontSize,
                              fontWeight: resctaFontWeight,
                            }}
                          >
                            <span
                              className="responsive-block-editor-addons-inline-editing"
                              style={{
                                color: resctaLinkColor,
                                fontSize: resctaFontSize,
                              }}
                            >
                              {resctaText}
                            </span>
                          </a>
                        )}

                        {resctaType === "button" && (
                          <div
                            className={classnames(
                              "responsive-block-editor-addons-ifb-button-wrapper"
                            )}
                          >
                            <a
                              className={ctaBtnClass}
                              target={target}
                              rel={rel}
                              style={{
                                borderWidth: resctaBorderWidth,
                                borderStyle: resctaBorderStyle,
                                borderRadius: resctaBorderRadius,
                                paddingTop: ctaBtnVertPadding,
                                paddingBottom: ctaBtnVertPadding,
                                paddingLeft: ctaBtnHrPadding,
                                paddingRight: ctaBtnHrPadding,
                                fontSize: resctaFontSize,
                                fontWeight: resctaFontWeight,
                              }}
                            >
                              <span className="responsive-block-editor-addons-ifb-cta-content-wrapper">
                                <span
                                  className="responsive-block-editor-addons-inline-editing "
                                  style={{
                                    fontSize: resctaFontSize,
                                  }}
                                >
                                  {resctaText}
                                </span>
                              </span>
                            </a>
                          </div>
                        )}
                      </div>
                    </div>
                  </Fragment>
                )}

                {(imgiconPosition == "left" || imgiconPosition == "right") && (
                  <Fragment>
                    <div className="responsive-block-editor-addons-ifb-title-wrap">
                      {resshowPrefix && (
                        <RichText
                          tagName="div"
                          value={resprefixTitle}
                          placeholder={__(
                            "Write a Prefix",
                            "responsive-block-editor-addons"
                          )}
                          className="responsive-block-editor-addons-ifb-title-prefix"
                          multiline={false}
                          onChange={(value) => {
                            setAttributes({ resprefixTitle: value });
                          }}
                          style={{
                            color: resprefixColor,
                            fontSize: resprefixFontSize,
                            fontWeight: resprefixFontWeight,
                            lineHeight: resprefixLineHeight,
                            marginBottom: resprefixSpace,
                          }}
                        />
                      )}
                      {"none" !== resseperatorStyle &&
                        seperator_position == "after_prefix" &&
                        seperator_html}
                      {resshowTitle && (
                        <RichText
                          tagName={resheadingTag}
                          placeholder={__(
                            "Write a Heading",
                            "responsive-block-editor-addons"
                          )}
                          value={resinfoBlockTitle}
                          className="responsive-block-editor-addons-ifb-title"
                          onChange={(value) =>
                            setAttributes({ resinfoBlockTitle: value })
                          }
                          multiline={false}
                          style={{
                            color: resheadingColor,
                            fontWeight: resheadFontWeight,
                            lineHeight: resheadLineHeight,
                            marginBottom: resheadSpace,
                          }}
                        />
                      )}
                    </div>
                    {"none" !== resseperatorStyle &&
                      seperator_position == "after_title" &&
                      show_seperator &&
                      seperator_html}
                    <div className="responsive-block-editor-addons-ifb-text-wrap">
                      {resshowDesc && (
                        <RichText
                          tagName="p"
                          value={resDescHeading}
                          placeholder={__(
                            "Write a Description",
                            "responsive-block-editor-addons"
                          )}
                          className="responsive-block-editor-addons-ifb-desc"
                          value={resDescHeading}
                          style={{
                            color: ressubheadingColor,
                            fontSize: ressubHeadFontSize,
                            fontWeight: ressubHeadFontWeight,
                            lineHeight: ressubHeadLineHeight,
                            marginBottom: ressubHeadSpace,
                          }}
                          onChange={(value) =>
                            setAttributes({ resDescHeading: value })
                          }
                        />
                      )}
                      {"none" !== resseperatorStyle &&
                        seperator_position == "after_desc" &&
                        seperator_html}
                      <div className="responsive-block-editor-addons-ifb-cta responsive-block-editor-addons-infobox-cta-link-style">
                        {resctaType === "text" && (
                          <a
                            target={target}
                            className="responsive-block-editor-addons-infobox-cta-link"
                            rel={rel}
                            style={{
                              color: resctaLinkColor,
                              paddingTop: ctaBtnVertPadding,
                              paddingBottom: ctaBtnVertPadding,
                              paddingLeft: ctaBtnHrPadding,
                              paddingRight: ctaBtnHrPadding,
                              fontSize: resctaFontSize,
                              fontWeight: resctaFontWeight,
                            }}
                          >
                            <span
                              className="responsive-block-editor-addons-inline-editing"
                              style={{
                                color: resctaLinkColor,
                                fontSize: resctaFontSize,
                              }}
                            >
                              {resctaText}
                            </span>
                          </a>
                        )}

                        {resctaType === "button" && (
                          <div
                            className={classnames(
                              "responsive-block-editor-addons-ifb-button-wrapper"
                            )}
                          >
                            <a
                              className={ctaBtnClass}
                              target={target}
                              rel={rel}
                              style={{
                                borderWidth: resctaBorderWidth,
                                borderStyle: resctaBorderStyle,
                                borderRadius: resctaBorderRadius,
                                paddingTop: ctaBtnVertPadding,
                                paddingBottom: ctaBtnVertPadding,
                                paddingLeft: ctaBtnHrPadding,
                                paddingRight: ctaBtnHrPadding,
                                fontSize: resctaFontSize,
                                fontWeight: resctaFontWeight,
                              }}
                            >
                              <span className="responsive-block-editor-addons-ifb-cta-content-wrapper">
                                <span
                                  className="responsive-block-editor-addons-inline-editing "
                                  style={{
                                    fontSize: resctaFontSize,
                                  }}
                                >
                                  {resctaText}
                                </span>
                              </span>
                            </a>
                          </div>
                        )}
                      </div>
                    </div>
                  </Fragment>
                )}
              </div>

              {imgiconPosition == "right" && icon_image_html}
            </div>
          </div>
        </InfoBlock>
      </Fragment>,
    ];
  }
}
