/**
 * BLOCK: Responsive Blocks Team
 */

// Import block dependencies and components
import Edit from "./components/edit";
import Save from "./components/save";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Internationalization
const { __ } = wp.i18n;

// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("responsive-block-editor-addons/info-block", {
  title: __("Info Block", "responsive-block-editor-addons"),
  description: __(
    "This block allows you to add icon or image along with heading and description.",
    "responsive-block-editor-addons"
  ),
  icon: "align-left",
  category: "responsive_block_editor_addons",
  keywords: [
    __("information", "responsive-block-editor-addons"),
    __("info", "responsive-block-editor-addons"),
    __("responsive", "responsive-block-editor-addons"),
  ],
  attributes: {
    inheritFromTheme: {
      type: "boolean",
      default: false,
    },
    resprefixTitle: {
      source: "html",
      selector: "span.responsive-block-editor-addons-ifb-title-prefix",
      default: "Prefix",
    },
    classMigrate: {
      type: "boolean",
      default: false,
    },
    resinfoBlockTitle: {
      source: "html",
      selector: "h1,h2,h3,h4,h5,h6",
      default: "Info Box",
    },
    resDescHeading: {
      source: "html",
      selector: "p",
      default:
        "Click here to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.",
    },
    resheadingAlign: {
      type: "string",
      default: "center",
    },
    resheadingColor: {
      type: "string",
    },
    ressubheadingColor: {
      type: "string",
    },
    resprefixColor: {
      type: "string",
    },
    icon: {
      type: "string",
      default: "fa fa-star",
    },
    imgiconPosition: {
      type: "string",
      default: "above-title",
    },
    resIconSize: {
      type: "number",
      default: 40,
    },
    iconColor: {
      type: "string",
      default: "#333",
    },
    resprefixFontSize: {
      type: "number",
    },
    resprefixFontWeight: {
      type: "string",
    },
    resprefixLineHeight: {
      type: "number",
    },
    resheadingTag: {
      type: "string",
      default: "h3",
    },
    resheadFontSize: {
      type: "number",
    },
    resheadFontSizeMobile: {
      type: "number",
    },
    resheadFontSizeTablet: {
      type: "number",
    },
    resheadFontWeight: {
      type: "string",
    },
    resheadLineHeight: {
      type: "number",
    },
    ressubHeadFontSize: {
      type: "number",
    },
    ressubHeadFontWeight: {
      type: "string",
    },
    ressubHeadLineHeight: {
      type: "number",
    },
    resheadSpace: {
      type: "number",
      default: 10,
    },
    ressubHeadSpace: {
      type: "number",
      default: 10,
    },
    resseperatorSpace: {
      type: "number",
      default: 10,
    },
    resiconimgBorderRadius: {
      type: "number",
      default: 0,
    },
    source_type: {
      type: "string",
      default: "icon",
    },
    ressourceAlign: {
      type: "string",
      default: "top",
    },
    resctaTarget: {
      type: "boolean",
      default: false,
    },
    ctaIcon: {
      type: "string",
      default: "",
    },
    resseperatorPosition: {
      type: "string",
      default: "after_title",
    },
    resseperatorStyle: {
      type: "string",
      default: "solid",
    },
    resseperatorColor: {
      type: "string",
      default: "#333",
    },
    resseperatorWidth: {
      type: "number",
      default: 30,
    },
    resseparatorWidthType: {
      type: "string",
      default: "%",
    },
    resseperatorThickness: {
      type: "number",
      default: 2,
    },
    resctaType: {
      type: "string",
      default: "none",
    },
    resctaText: {
      type: "string",
      default: "Read More",
    },
    resctaLink: {
      type: "string",
      default: "#",
    },
    resctaLinkColor: {
      type: "string",
      default: "#333",
    },
    resctaFontSize: {
      type: "number",
    },
    resctaFontWeight: {
      type: "string",
    },
    resctaBtnLinkColor: {
      type: "string",
      default: "#333",
    },
    resctaBgColor: {
      type: "string",
      default: "transparent",
    },
    resctaBorderColor: {
      type: "string",
      default: "#333",
    },
    resctaBorderStyle: {
      type: "string",
      default: "solid",
    },
    ctaBtnVertPadding: {
      type: "number",
      default: 10,
    },
    ctaBtnHrPadding: {
      type: "number",
      default: 14,
    },
    resctaBorderWidth: {
      type: "number",
      default: 1,
    },
    resctaBorderRadius: {
      type: "number",
      default: 0,
    },
    resprefixSpace: {
      type: "number",
      default: 5,
    },
    iconLeftMargin: {
      type: "number",
      default: 0,
    },
    iconRightMargin: {
      type: "number",
      default: 0,
    },
    iconTopMargin: {
      type: "number",
      default: 5,
    },
    iconBottomMargin: {
      type: "number",
      default: 5,
    },
    iconImage: {
      type: "object",
      default: {
        url: "",
        alt: "InfoBlock placeholder img",
      },
    },
    imageSize: {
      type: "string",
      default: "thumbnail",
    },
    imageWidth: {
      type: "number",
      default: 120,
    },
    imageWidthType: {
      type: "boolean",
      default: true,
    },
    stack: {
      type: "string",
      default: "tablet",
    },
    resshowPrefix: {
      type: "boolean",
      default: true,
    },
    resshowTitle: {
      type: "boolean",
      default: true,
    },
    resshowDesc: {
      type: "boolean",
      default: true,
    },
    blockBorderStyle: {
      type: "string",
      default: "none",
    },
    blockBorderWidth: {
      type: "number",
      default: 1,
    },
    blockBorderRadius: {
      type: "number",
    },
    blockBorderColor: {
      type: "string",
    },
    boxShadowColor: {
      type: "string",
    },
    boxShadowHOffset: {
      type: "number",
      default: 0,
    },
    boxShadowVOffset: {
      type: "number",
      default: 0,
    },
    boxShadowBlur: {
      type: "number",
    },
    boxShadowSpread: {
      type: "number",
    },
    boxShadowPosition: {
      type: "string",
      default: "outset",
    },
    counterId: {
      type: "string",
      default: 1,
    },
    boxBackgroundColor: {
      type: "string",
      default: "#ffffff",
    },
    contentPadding: {
      type: "number",
      default: 0,
    },
    opacity: {
      type: "number",
      default: 100,
    },
    imgURL: {
      type: "string",
    },
    imgID: {
      type: "number",
    },
    imgAlt: {
      type: "string",
      source: "attribute",
      attribute: "alt",
      selector: "img",
    },
    dimRatio: {
      type: "number",
      default: 50,
    },
    hoverctaBtnLinkColor: {
      type: "string",
      default: "#333",
    },
    hoverctaBgColor: {
      type: "string",
      default: "transparent",
    },
    hoverctaBorderColor: {
      type: "string",
      default: "#333",
    },
    imagePosition: {
      type: "string",
      default: "center center",
    },
    imageRepeat: {
      type: "string",
      default: "no-repeat",
    },
    thumbsize: {
      type: "string",
      default: "cover",
    },
    backgroundAttachment: {
      type: "string",
      default: "scroll",
    },
    sepSpace: {
      type: "number",
      default: 10,
    },
  },

  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
