/**
 * External dependencies
 */

import isUndefined from "lodash/isUndefined";
import pickBy from "lodash/pickBy";
import moment from "moment";
import classnames from "classnames";
import Inspector from "./inspector";
import PostGridImage from "./image";
import AlignClass from ".././align-classes";
import ContentTmClasses from ".././classes";
import DayAlignClass from ".././day-align-classes";
import renderSVG from "../../../renderIcon";
import ResponsiveBlocksIcon from "../../../ResponsiveBlocksIcon.json";
import generateCSSUnit from "../../../generateCSSUnit";
import React from "react";
import Style from "style-it";

const { compose } = wp.compose;

const { Component, Fragment } = wp.element;

const { __ } = wp.i18n;

const { decodeEntities } = wp.htmlEntities;

const { withSelect } = wp.data;

const {
  Placeholder,
  Spinner,
  Toolbar,
  Icon,
  SelectControl,
  PanelBody,
} = wp.components;

const {
  BlockAlignmentToolbar,
  BlockControls,
  InspectorControls,
} = wp.blockEditor;

let svg_icons = Object.keys(ResponsiveBlocksIcon);

class LatestPostsBlock extends Component {
  constructor() {
    super(...arguments);
    this.onSelectTaxonomyType = this.onSelectTaxonomyType.bind(this);
  }
  onSelectTaxonomyType(value) {
    const { setAttributes } = this.props;

    setAttributes({ taxonomyType: value });
    setAttributes({ categories: "" });
  }
  componentDidMount() {
    this.props.setAttributes({ block_id: this.props.clientId.substr(0, 8) });
  }
  render() {
    const {
      attributes,
      setAttributes,
      latestPosts,
      taxonomyList,
      categoriesList,
    } = this.props;

    // Check if there are posts
    const hasPosts = Array.isArray(latestPosts) && latestPosts.length;

    // Check the post type
    const isPost = "post" === attributes.postType;

    if (!hasPosts) {
      return (
        <Fragment>
          <Inspector {...{ setAttributes, ...this.props }} />
          <Placeholder
            icon="admin-post"
            label={__("Post Timeline", "responsive-block-editor-addons")}
          >
            {!Array.isArray(latestPosts) ? (
              <Spinner />
            ) : (
              __("No posts found.", "responsive-block-editor-addons")
            )}
          </Placeholder>
        </Fragment>
      );
    }

    // Removing posts from display should be instant.
    const displayPosts =
      latestPosts.length > attributes.postsToShow
        ? latestPosts.slice(0, attributes.postsToShow)
        : latestPosts;

    // Get the section tag
    const SectionTag = attributes.sectionTag
      ? attributes.sectionTag
      : "section";

    // Get the section title tag
    const SectionTitleTag = attributes.sectionTitleTag
      ? attributes.sectionTitleTag
      : "h2";

    // Get the post title tag
    const PostTag = attributes.postTitleTag ? attributes.postTitleTag : "h3";

    var content_align_class = AlignClass(this.props.attributes, 0); // Get classname for layout alignment
    var day_align_class = DayAlignClass(this.props.attributes, 0); // Get classname for day alignment.

    var boxShadowPositionCSS = attributes.boxShadowPosition;

    if ("outset" === attributes.boxShadowPosition) {
      boxShadowPositionCSS = "";
    }

    let taxonomyListOptions = [{ value: "", label: __("Select Taxonomy") }];

    let categoryListOptions = [{ value: "", label: __("All") }];

    if ("" != taxonomyList) {
      Object.keys(taxonomyList).map((item, thisIndex) => {
        return taxonomyListOptions.push({
          value: taxonomyList[item]["name"],
          label: taxonomyList[item]["label"],
        });
      });
    }

    if ("" != categoriesList) {
      Object.keys(categoriesList).map((item, thisIndex) => {
        return categoryListOptions.push({
          value: categoriesList[item]["id"],
          label: categoriesList[item]["name"],
        });
      });
    }

    return (
      <Fragment>
        <InspectorControls>
          <PanelBody title={__("Query")} initialOpen={true}>
            {"" != taxonomyList && (
              <SelectControl
                label={__("Taxonomy")}
                value={attributes.taxonomyType}
                onChange={(value) => this.onSelectTaxonomyType(value)}
                options={taxonomyListOptions}
              />
            )}
            {"" != categoriesList && (
              <Fragment>
                <SelectControl
                  label={taxonomyList[attributes.taxonomyType]["label"]}
                  value={attributes.categories}
                  onChange={(value) => setAttributes({ categories: value })}
                  options={categoryListOptions}
                />
              </Fragment>
            )}
          </PanelBody>
        </InspectorControls>
        <Inspector {...{ setAttributes, ...this.props }} />
        <Style>
          {`
		  .wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__icon-new svg {
		   width: ${generateCSSUnit(attributes.iconSize, "px")};
		   height: ${generateCSSUnit(attributes.iconSize, "px")};
		   fill: ${attributes.iconColor};
	   }

	   .wp-block-responsive-block-editor-addons-post-timeline-${
       attributes.block_id
     } .responsive-block-editor-addons-timeline__icon-new svg:hover {
		   fill: ${attributes.iconFocus};
	   }

		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__marker {
			border: ${generateCSSUnit(attributes.borderWidth, "px solid")};
			border-color: ${attributes.separatorBorder};
			background-color: ${attributes.separatorBg};
			min-width: ${generateCSSUnit(attributes.bgSize, "px")};
 		   min-height: ${generateCSSUnit(attributes.bgSize, "px")};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__marker:hover {
			border-color: ${attributes.borderFocus};
			background-color: ${attributes.iconBgFocus};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__line {
			background-color: ${attributes.connectorColor};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__line:hover {
			background-color: ${attributes.separatorFillColor};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__link_parent {
			background-color: ${attributes.continuebgColor};
			border: 1px solid ${attributes.borderColor};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__link_parent:hover {
			background-color: ${attributes.continuebghColor};
			border: 1px solid ${attributes.borderHColor};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__link_parent .responsive-block-editor-addons-timeline__link {
			color: ${attributes.continueColor} !important;
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__link_parent .responsive-block-editor-addons-timeline__link:hover {
			color: ${attributes.hColor} !important;
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__center-block .responsive-block-editor-addons-timeline__marker {
			margin-left: ${generateCSSUnit(attributes.horSpace, "px")};
			margin-right: ${generateCSSUnit(attributes.horSpace, "px")};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__left-block .responsive-block-editor-addons-timeline__day-new {
			margin-left: ${generateCSSUnit(attributes.horSpace, "px")};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__right-block .responsive-block-editor-addons-timeline__day-new {
			margin-left: ${generateCSSUnit(attributes.horSpace, "px")};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__field.responsive-block-editor-addons-timeline__field-wrap {
			margin-bottom: ${generateCSSUnit(attributes.verSpace, "px")};
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__left-block .responsive-block-editor-addons-timeline__line{
			left: calc(${attributes.bgSize}px/2);
		}
		.wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__right-block .responsive-block-editor-addons-timeline__line{
			right: calc(${attributes.bgSize}px/2);
		}
		.editor-styles-wrapper .wp-block-responsive-block-editor-addons-post-timeline-${
      attributes.block_id
    } .responsive-block-editor-addons-timeline__main .responsive-block-editor-addons-timeline__post p{
			line-height: ${attributes.contentLineHeight};
		}
		@media(max-width:767px){
			.wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__center-block.responsive-block-editor-addons-timeline__responsive-mobile .responsive-block-editor-addons-timeline__line{
				left: calc(${attributes.bgSize}px/2);
				right: calc(${attributes.bgSize}px/2);
			}
			.wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__left-block.responsive-block-editor-addons-timeline__responsive-mobile .responsive-block-editor-addons-timeline__line{
				left: calc(${attributes.bgSize}px/2);
			}
			.wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__right-block.responsive-block-editor-addons-timeline__responsive-mobile .responsive-block-editor-addons-timeline__line{
				right: calc(${attributes.bgSize}px/2);
			}

		}
		@media(max-width:976px){
			.wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__center-block.responsive-block-editor-addons-timeline__responsive-tablet .responsive-block-editor-addons-timeline__line{
				left: calc(${attributes.bgSize}px/2);
				right: calc(${attributes.bgSize}px/2);
			}
			.wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__left-block.responsive-block-editor-addons-timeline__responsive-tablet .responsive-block-editor-addons-timeline__line{
				left: calc(${attributes.bgSize}px/2);
			}
			.wp-block-responsive-block-editor-addons-post-timeline-${
        attributes.block_id
      } .responsive-block-editor-addons-timeline__right-block.responsive-block-editor-addons-timeline__responsive-tablet .responsive-block-editor-addons-timeline__line{
				right: calc(${attributes.bgSize}px/2);
			}
		}
	   `}
        </Style>
        <BlockControls>
          <BlockAlignmentToolbar
            value={attributes.align}
            onChange={(value) => {
              setAttributes({ align: value });
            }}
            controls={["center", "wide", "full"]}
          />
        </BlockControls>
        <SectionTag
          className={classnames(
            this.props.className,
            `wp-block-responsive-block-editor-addons-post-timeline-${attributes.block_id}`,
            "responsive-block-editor-addons-block-post-grid",
            ...ContentTmClasses(this.props.attributes)
          )}
        >
          {attributes.displaySectionTitle && attributes.sectionTitle && (
            <SectionTitleTag className="responsive-block-editor-addons-post-grid-section-title">
              {attributes.sectionTitle}
            </SectionTitleTag>
          )}
          <div className="responsive-block-editor-addons-timeline__main">
            <div className="responsive-block-editor-addons-timeline__days">
              {displayPosts.map(
                (post, i) => (
                  (content_align_class = AlignClass(this.props.attributes, i)),
                  (day_align_class = DayAlignClass(this.props.attributes, i)),
                  (
                    <article
                      key={i}
                      id={"post-" + post.id}
                      className={classnames(
                        "post-" + post.id,
                        "responsive-block-editor-addons-timeline__field",
                        "responsive-block-editor-addons-timeline__field-wrap",
                        post.featured_image_src && attributes.displayPostImage
                          ? "has-post-thumbnail"
                          : null
                      )}
                    >
                      <div className={content_align_class}>
                        <div className="responsive-block-editor-addons-timeline__marker responsive-block-editor-addons-timeline__out-view-icon">
                          <span className="responsive-block-editor-addons-timeline__icon-new responsive-block-editor-addons-timeline__out-view-icon">
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              viewBox="0 0 448 512"
                            >
                              <path d="M436 160H12c-6.6 0-12-5.4-12-12v-36c0-26.5 21.5-48 48-48h48V12c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v52h128V12c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v52h48c26.5 0 48 21.5 48 48v36c0 6.6-5.4 12-12 12zM12 192h424c6.6 0 12 5.4 12 12v260c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V204c0-6.6 5.4-12 12-12zm116 204c0-6.6-5.4-12-12-12H76c-6.6 0-12 5.4-12 12v40c0 6.6 5.4 12 12 12h40c6.6 0 12-5.4 12-12v-40zm0-128c0-6.6-5.4-12-12-12H76c-6.6 0-12 5.4-12 12v40c0 6.6 5.4 12 12 12h40c6.6 0 12-5.4 12-12v-40zm128 128c0-6.6-5.4-12-12-12h-40c-6.6 0-12 5.4-12 12v40c0 6.6 5.4 12 12 12h40c6.6 0 12-5.4 12-12v-40zm0-128c0-6.6-5.4-12-12-12h-40c-6.6 0-12 5.4-12 12v40c0 6.6 5.4 12 12 12h40c6.6 0 12-5.4 12-12v-40zm128 128c0-6.6-5.4-12-12-12h-40c-6.6 0-12 5.4-12 12v40c0 6.6 5.4 12 12 12h40c6.6 0 12-5.4 12-12v-40zm0-128c0-6.6-5.4-12-12-12h-40c-6.6 0-12 5.4-12 12v40c0 6.6 5.4 12 12 12h40c6.6 0 12-5.4 12-12v-40z" />
                            </svg>
                          </span>
                        </div>
                        <div className={day_align_class}>
                          <div
                            className="responsive-block-editor-addons-timeline__events-new"
                            style={{
                              marginBottom: attributes.blockSpace,
                            }}
                          >
                            <div
                              className="responsive-block-editor-addons-timeline__events-inner-new"
                              style={{
                                backgroundColor: attributes.bgColor
                                  ? attributes.bgColor
                                  : "#e4e4e4",
                                borderRadius: attributes.borderRadius,
                              }}
                            >
                              <div className="responsive-block-editor-addons-timeline__date-hide responsive-block-editor-addons-timeline__date-inner">
                                {attributes.displayPostDate && post.date_gmt && (
                                  <time
                                    dateTime={moment(post.date_gmt)
                                      .utc()
                                      .format()}
                                    className={
                                      "responsive-block-editor-addons-timeline__date-new"
                                    }
                                    style={{
                                      lineHeight: attributes.dateLineHeight,
                                      fontWeight: attributes.dateFontWeight,
                                      fontSize: attributes.dateFontSize,
                                    }}
                                  >
                                    {moment(post.date_gmt)
                                      .local()
                                      .format(
                                        "MMMM DD, Y",
                                        "responsive-block-editor-addons"
                                      )}
                                  </time>
                                )}
                              </div>
                              {attributes.displayPostImage &&
                              post.featured_media ? (
                                <PostGridImage
                                  {...this.props}
                                  imgAlt={
                                    decodeEntities(
                                      post.title.rendered.trim()
                                    ) ||
                                    __(
                                      "(Untitled)",
                                      "responsive-block-editor-addons"
                                    )
                                  }
                                  imgClass={`wp-image-${post.featured_media.toString()}`}
                                  imgID={post.featured_media.toString()}
                                  imgSize={attributes.imageSize}
                                  imgSizeLandscape={post.featured_image_src}
                                  imgSizeSquare={post.featured_image_src_square}
                                  imgLink={post.link}
                                />
                              ) : null}
                              <div
                                className="responsive-block-editor-addons-content"
                                style={{
                                  padding: attributes.contentPadding,
                                }}
                              >
                                {attributes.displayPostTitle && (
                                  <PostTag
                                    className="responsive-block-editor-addons-block-post-grid-title"
                                    style={{
                                      marginBottom: attributes.headingSpace,
                                    }}
                                  >
                                    <a
                                      href={post.link}
                                      target="_blank"
                                      rel="bookmark"
                                      style={{
                                        color: attributes.headingColor
                                          ? attributes.headingColor
                                          : "#333",
                                        lineHeight:
                                          attributes.headingLineHeight,
                                        fontWeight:
                                          attributes.headingFontWeight,
                                        fontSize: attributes.headingFontSize,
                                      }}
                                    >
                                      {decodeEntities(
                                        post.title.rendered.trim()
                                      ) ||
                                        __(
                                          "(Untitled)",
                                          "responsive-block-editor-addons"
                                        )}
                                    </a>
                                  </PostTag>
                                )}

                                {isPost && (
                                  <div
                                    className="responsive-block-editor-addons-block-post-grid-byline"
                                    style={{
                                      marginBottom: attributes.authorSpace,
                                    }}
                                  >
                                    {attributes.displayPostAuthor &&
                                      post.author_info.display_name && (
                                        <div className="responsive-block-editor-addons-block-post-grid-author">
                                          <a
                                            className="responsive-block-editor-addons-text-link"
                                            target="_blank"
                                            href={post.author_info.author_link}
                                            style={{
                                              color: attributes.authorColor
                                                ? attributes.authorColor
                                                : "#626e81",
                                              lineHeight:
                                                attributes.authorLineHeight,
                                              fontWeight:
                                                attributes.authorFontWeight,
                                              fontSize:
                                                attributes.authorFontSize,
                                            }}
                                          >
                                            {post.author_info.display_name}
                                          </a>
                                        </div>
                                      )}
                                  </div>
                                )}

                                <div className="responsive-block-editor-addons-block-post-grid-excerpt">
                                  {attributes.displayPostExcerpt &&
                                    post.excerpt && (
                                      <div
                                        className="responsive-block-editor-addons-timeline__post"
                                        style={{
                                          color: attributes.textColor
                                            ? attributes.textColor
                                            : "#333",
                                          fontWeight:
                                            attributes.contentFontWeight,
                                          fontSize: attributes.contentFontSize,
                                        }}
                                      >
                                        <div
                                          dangerouslySetInnerHTML={{
                                            __html: truncate(
                                              post.excerpt.rendered,
                                              attributes.excerptLength
                                            ),
                                          }}
                                        />
                                      </div>
                                    )}

                                  {attributes.displayPostLink && (
                                    <div
                                      className="responsive-block-editor-addons-timeline__link_parent"
                                      style={{
                                        boxShadow:
                                          generateCSSUnit(
                                            attributes.boxShadowHOffset,
                                            "px"
                                          ) +
                                          " " +
                                          generateCSSUnit(
                                            attributes.boxShadowVOffset,
                                            "px"
                                          ) +
                                          " " +
                                          generateCSSUnit(
                                            attributes.boxShadowBlur,
                                            "px"
                                          ) +
                                          " " +
                                          generateCSSUnit(
                                            attributes.boxShadowSpread,
                                            "px"
                                          ) +
                                          " " +
                                          attributes.boxShadowColor +
                                          " " +
                                          boxShadowPositionCSS,
                                      }}
                                    >
                                      <a
                                        className="responsive-block-editor-addons-timeline__link"
                                        href={post.link}
                                        target="_blank"
                                        rel="bookmark"
                                        style={{
                                          lineHeight:
                                            attributes.continueLineHeight,
                                          fontWeight:
                                            attributes.continueFontWeight,
                                          fontSize: attributes.continueFontSize,
                                        }}
                                      >
                                        {attributes.readMoreText}
                                      </a>
                                    </div>
                                  )}
                                </div>
                                <div className="responsive-block-editor-addons-timeline__arrow"></div>
                              </div>
                            </div>
                          </div>
                        </div>
                        <div className="responsive-block-editor-addons-timeline__date-new responsive-block-editor-addons-timeline__date-outer">
                          {attributes.displayPostDate && post.date_gmt && (
                            <time
                              dateTime={moment(post.date_gmt).utc().format()}
                              className={
                                "responsive-block-editor-addons-timeline__date-new"
                              }
                              style={{
                                lineHeight: attributes.dateLineHeight,
                                fontWeight: attributes.dateFontWeight,
                                fontSize: attributes.dateFontSize,
                              }}
                            >
                              {moment(post.date_gmt)
                                .local()
                                .format(
                                  "MMMM DD, Y",
                                  "responsive-block-editor-addons"
                                )}
                            </time>
                          )}
                        </div>
                      </div>
                    </article>
                  )
                )
              )}
            </div>
            <div
              className="responsive-block-editor-addons-timeline__line"
              style={{
                width: attributes.connectorWidth,
              }}
            >
              <div className="responsive-block-editor-addons-timeline__line__inner"></div>
            </div>
          </div>
        </SectionTag>
      </Fragment>
    );
  }
}

export default compose([
  withSelect((select, props) => {
    const { order, categories, taxonomyType, postType } = props.attributes;

    const { getEntityRecords } = select("core");

    let allTaxonomy = responsive_globals.all_taxonomy;
    let currentTax = allTaxonomy[postType];
    let taxonomy = "";
    let categoriesList = [];
    let rest_base = "";

    if ("undefined" != typeof currentTax) {
      if ("undefined" != typeof currentTax["taxonomy"][taxonomyType]) {
        rest_base =
          currentTax["taxonomy"][taxonomyType]["rest_base"] == false ||
          currentTax["taxonomy"][taxonomyType]["rest_base"] == null
            ? currentTax["taxonomy"][taxonomyType]["name"]
            : currentTax["taxonomy"][taxonomyType]["rest_base"];
      }

      if ("" != taxonomyType) {
        if (
          "undefined" != typeof currentTax["terms"] &&
          "undefined" != typeof currentTax["terms"][taxonomyType]
        ) {
          categoriesList = currentTax["terms"][taxonomyType];
        }
      }
    }

    const latestPostsQuery = pickBy(
      {
        order,
        orderby: props.attributes.orderBy,
        per_page: props.attributes.postsToShow,
        offset: props.attributes.offset,
        exclude: [wp.data.select("core/editor").getCurrentPostId()],
      },
      (value) => !isUndefined(value)
    );

    latestPostsQuery[rest_base] = categories;

    return {
      latestPosts: getEntityRecords(
        "postType",
        props.attributes.postType,
        latestPostsQuery
      ),
      categoriesList: categoriesList,
      taxonomyList:
        "undefined" != typeof currentTax ? currentTax["taxonomy"] : [],
    };
  }),
])(LatestPostsBlock);

// Truncate excerpt
function truncate(str, no_words) {
  return str.split(" ").splice(0, no_words).join(" ");
}
