/**
 * BLOCK: Responsive Blocks Column
 */

// Import block dependencies and components
import Edit from "./components/edit";
import Save from "./components/save";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Internationalization
const { __ } = wp.i18n;

// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("responsive-block-editor-addons/section", {
  title: __("Section", "responsive-block-editor-addons"),
  description: __(
    "This block allows you to add section in your webpage.",
    "responsive-block-editor-addons"
  ),
  icon: "welcome-widgets-menus",
  category: "responsive_block_editor_addons",
  keywords: [
    __("section", "responsive-block-editor-addons"),
    __("responsive", "responsive-block-editor-addons"),
  ],
  supports: {
    align: ["wide", "full"],
  },
  attributes: {
    contentWidth: {
      type: "string",
      default: "boxed",
    },
    blockId: {
      type: "string",
    },
    width: {
      type: "number",
      default: 900,
    },
    innerWidth: {
      type: "number",
      default: 1140,
    },
    innerWidthType: {
      type: "string",
      default: "px",
    },
    themeWidth: {
      type: "boolean",
      default: false,
    },
    topPadding: {
      type: "number",
      default: 20,
    },
    topPaddingMobile: {
      type: "number",
      default: 20,
    },
    topPaddingTablet: {
      type: "number",
      default: 20,
    },
    bottomPadding: {
      type: "number",
      default: 20,
    },
    bottomPaddingMobile: {
      type: "number",
      default: 20,
    },
    bottomPaddingTablet: {
      type: "number",
      default: 20,
    },
    leftPadding: {
      type: "number",
      default: 20,
    },
    leftPaddingMobile: {
      type: "number",
      default: 20,
    },
    leftPaddingTablet: {
      type: "number",
      default: 20,
    },
    rightPadding: {
      type: "number",
      default: 20,
    },
    rightPaddingMobile: {
      type: "number",
      default: 20,
    },
    rightPaddingTablet: {
      type: "number",
      default: 20,
    },
    topTabletPadding: {
      type: "number",
      default: 20,
    },
    bottomTabletPadding: {
      type: "number",
      default: 20,
    },
    leftTabletPadding: {
      type: "number",
      default: 20,
    },
    rightTabletPadding: {
      type: "number",
      default: 20,
    },
    topMobilePadding: {
      type: "number",
      default: 20,
    },
    bottomMobilePadding: {
      type: "number",
      default: 20,
    },
    leftMobilePadding: {
      type: "number",
      default: 20,
    },
    rightMobilePadding: {
      type: "number",
      default: 20,
    },
    topMargin: {
      type: "number",
      default: 0,
    },
    bottomMargin: {
      type: "number",
      default: 0,
    },
    leftMargin: {
      type: "number",
      default: 0,
    },
    rightMargin: {
      type: "number",
      default: 0,
    },
    topTabletMargin: {
      type: "number",
      default: 0,
    },
    bottomTabletMargin: {
      type: "number",
      default: 0,
    },
    leftTabletMargin: {
      type: "number",
      default: 0,
    },
    rightTabletMargin: {
      type: "number",
      default: 0,
    },
    topMobileMargin: {
      type: "number",
      default: 0,
    },
    bottomMobileMargin: {
      type: "number",
      default: 0,
    },
    leftMobileMargin: {
      type: "number",
      default: 0,
    },
    rightMobileMargin: {
      type: "number",
      default: 0,
    },
    blockBorderStyle: {
      type: "string",
      default: "none",
    },
    blockBorderWidth: {
      type: "number",
      default: 1,
    },
    blockBorderRadius: {
      type: "number",
      default: 0,
    },
    blockBorderColor: {
      type: "string",
    },
    sectionTag: {
      type: "string",
      default: "section",
    },
    opacity: {
      type: "number",
      default: 20,
    },
    colorLocation1: {
      type: "number",
      default: 0,
    },
    colorLocation2: {
      type: "number",
      default: 100,
    },
    gradientDirection: {
      type: "number",
      default: 90,
    },
    backgroundImage: {
      type: "string",
    },
    backgroundPosition: {
      type: "string",
      default: "center-center",
    },
    backgroundSize: {
      type: "string",
      default: "cover",
    },
    backgroundRepeat: {
      type: "string",
      default: "no-repeat",
    },
    backgroundAttachment: {
      type: "string",
      default: "scroll",
    },
    backgroundImageColor: {
      type: "string",
    },
    overlayType: {
      type: "string",
      default: "color",
    },
    gradientOverlayColor1: {
      type: "string",
    },
    gradientOverlayColor2: {
      type: "string",
    },
    gradientOverlayType: {
      type: "string",
      default: "linear",
    },
    gradientOverlayLocation1: {
      type: "number",
      default: 0,
    },
    gradientOverlayLocation2: {
      type: "number",
      default: 100,
    },
    gradientOverlayAngle: {
      type: "number",
      default: 0,
    },
    gradientOverlayPosition: {
      type: "string",
      default: "center center",
    },
    backgroundVideo: {
      type: "object",
    },
    backgroundColor: {
      type: "string",
    },
    backgroundColor1: {
      type: "string",
    },
    backgroundColor2: {
      type: "string",
    },
    backgroundType: {
      type: "string",
      default: "none",
    },
    boxShadowColor: {
      type: "string",
    },
    boxShadowHOffset: {
      type: "number",
      default: 0,
    },
    boxShadowVOffset: {
      type: "number",
      default: 0,
    },
    boxShadowBlur: {
      type: "number",
      default: 20,
    },
    boxShadowSpread: {
      type: "number",
      default: 20,
    },
    boxShadowPosition: {
      type: "string",
      default: "outset",
    },
    z_index: {
      type: "number",
      default: 1,
    },
  },

  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
