/**
 * Internal dependencies
 */
import Testimonial from "./testimonial";
import times from "lodash/times";
import classnames from "classnames";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const {
  RichText,
  AlignmentToolbar,
  MediaUpload,
  BlockControls,
  InnerBlocks,
  MediaUploadCheck,
  figure,
  URLInput,
} = wp.editor;
const { Button, Dashicon } = wp.components;

export default class Save extends Component {
  constructor() {
    super(...arguments);
  }

  render() {
    const {
      testimonialBlock,
      count,
      gutter,
      testimonialAlignment,
      testimonialTextColor,
      titleFontSize,
      titleLineHeight,
      titleFontWeight,
      titleTextTransform,
      nameFontSize,
      nameLineHeight,
      nameFontWeight,
      nameTextTransform,
      contentFontSize,
      contentLineHeight,
      contentFontWeight,
      contentTextTransform,
      imageSize,
      imageWidth,
      contentSpacing,
      titleSpacing,
      nameSpacing,
      imageSpacing,
    } = this.props.attributes;

    return (
      <div
        className={classnames(
          "wp-block-responsive-block-editor-addons-testimonial-wrapper",
          {
            "has-columns": count > 1,
            [`has-${count}-columns`]: count,
            "has-responsive-columns": count > 1,
            [`has-${gutter}-gutter`]: gutter,
          }
        )}
      >
        {testimonialBlock.map((test, index) => (
          <Testimonial {...this.props}>
            <RichText.Content
              tagName="div"
              className="responsive-block-editor-addons-testimonial-text"
              style={{
                textAlign: testimonialAlignment,
                fontSize: contentFontSize,
                lineHeight: contentLineHeight,
                fontWeight: contentFontWeight,
                textTransform: contentTextTransform,
                marginBottom: contentSpacing,
              }}
              value={testimonialBlock[index]["testimonialContent"]}
            />

            <div
              className="responsive-block-editor-addons-testimonial-info"
              style={{
                marginBottom: titleSpacing,
              }}
            >
              <div className="responsive-block-editor-addons-testimonial-inner-block">
                {testimonialBlock[index]["testimonialImgURL"] && (
                  <div
                    className="responsive-block-editor-addons-testimonial-avatar-wrap"
                    style={{
                      paddingRight: imageSpacing,
                    }}
                  >
                    <div
                      className="responsive-block-editor-addons-testimonial-image-wrap"
                      style={{
                        height: imageWidth + "px",
                        width: imageWidth + "px",
                      }}
                    >
                      <img
                        className="responsive-block-editor-addons-testimonial-avatar"
                        src={
                          testimonialBlock[index]["testimonialImgURL"].sizes[
                            imageSize
                          ]
                            ? testimonialBlock[index]["testimonialImgURL"]
                                .sizes[imageSize].url
                            : testimonialBlock[index]["testimonialImgURL"]
                                .sizes["full"].url
                        }
                        alt="avatar"
                        style={{
                          height: imageWidth + "px",
                          width: imageWidth + "px",
                        }}
                      />
                    </div>
                  </div>
                )}

                <div className="responsive-block-editor-addons-testimonial-details">
                  {testimonialBlock[index]["testimonialName"] && (
                    <RichText.Content
                      tagName="h2"
                      className="responsive-block-editor-addons-testimonial-name"
                      style={{
                        color: testimonialTextColor
                          ? testimonialTextColor
                          : "#32373c",
                        fontSize: nameFontSize,
                        lineHeight: nameLineHeight,
                        fontWeight: nameFontWeight,
                        textTransform: nameTextTransform,
                        marginBottom: nameSpacing,
                      }}
                      value={testimonialBlock[index]["testimonialName"]}
                    />
                  )}

                  {testimonialBlock[index]["testimonialTitle"] && (
                    <RichText.Content
                      tagName="small"
                      className="responsive-block-editor-addons-testimonial-title"
                      style={{
                        color: testimonialTextColor
                          ? testimonialTextColor
                          : "#32373c",
                        fontSize: titleFontSize,
                        lineHeight: titleLineHeight,
                        fontWeight: titleFontWeight,
                        textTransform: titleTextTransform,
                      }}
                      value={testimonialBlock[index]["testimonialTitle"]}
                    />
                  )}
                </div>
              </div>
            </div>
          </Testimonial>
        ))}
      </div>
    );
  }
}
