/**
 * Testimonial Block Wrapper
 */

// Setup the block
const { Component } = wp.element;

// Import block dependencies and components
import classnames from "classnames";
import generateCSSUnit from "../../../generateCSSUnit";
import { hexToRgba } from "../../../utils/index.js";

/**
 * Create a Testimonial wrapper Component
 */
export default class Testimonial extends Component {
  constructor(props) {
    super(...arguments);
  }

  render() {
    // Setup the attributes
    const {
      attributes: {
        testimonialImgURL,
        testimonialBackgroundColor,
        testimonialTextColor,
        testimonialFontSize,
        testimonialCiteAlign,
        borderRadius,
        padding,
        boxShadowColor,
        boxShadowHOffset,
        boxShadowVOffset,
        boxShadowBlur,
        boxShadowSpread,
        boxShadowPosition,
        opacity,
        backgroundPosition,
        backgroundRepeat,
        backgroundSize,
        secondaryBackgroundColor,
        gradientDegree,
        bgGradient,
        backgroundImage,
        imageShape,
      },
    } = this.props;

    var boxShadowPositionCSS = boxShadowPosition;

    var bgimage = backgroundImage ? backgroundImage : "";
    var tempsecondaryBackgroundColor = bgGradient
      ? secondaryBackgroundColor
      : testimonialBackgroundColor;
    var bggradient =
      "linear-gradient(" +
      gradientDegree +
      "deg," +
      hexToRgba(testimonialBackgroundColor || "#ffffff", opacity || 0) +
      "," +
      hexToRgba(tempsecondaryBackgroundColor || "#ffffff", opacity || 0) +
      "),url(" +
      bgimage +
      ")";

    if ("outset" === boxShadowPosition) {
      boxShadowPositionCSS = "";
    }

    return (
      <div
        style={{
          backgroundImage: bggradient,
          backgroundSize: backgroundSize,
          backgroundRepeat: backgroundRepeat,
          backgroundPosition: backgroundPosition,
          color: testimonialTextColor,
          borderRadius: borderRadius,
          padding: padding,
          boxShadow:
            generateCSSUnit(boxShadowHOffset, "px") +
            " " +
            generateCSSUnit(boxShadowVOffset, "px") +
            " " +
            generateCSSUnit(boxShadowBlur, "px") +
            " " +
            generateCSSUnit(boxShadowSpread, "px") +
            " " +
            boxShadowColor +
            " " +
            boxShadowPositionCSS,
        }}
        className={classnames(
          this.props.className,
          testimonialCiteAlign,
          { "responsive-block-editor-addons-has-avatar": testimonialImgURL },
          "responsive-block-editor-addons-font-size-" + testimonialFontSize,
          "responsive-block-editor-addons-block-testimonial",
          "image-shape-" + imageShape
        )}
      >
        {this.props.children}
      </div>
    );
  }
}
