/**
 * BLOCK: Responsive Blocks Testimonial
 */

// Import block dependencies and components
import Edit from "./components/edit";
import Save from "./components/save";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Internationalization
const { __ } = wp.i18n;
const ITEM_COUNT = 2;

const testimonialBlock = [];

for (var i = 1; i <= ITEM_COUNT; i++) {
  testimonialBlock.push({
    testimonialName: "",
    testimonialTitle: "",
    testimonialContent: "",
    testimonialImgURL: "",
    testimonialImgID: "",
  });
}
// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("responsive-block-editor-addons/testimonial", {
  title: __("Testimonial", "responsive-block-editor-addons"),
  description: __(
    "Add a user testimonial with a name and title.",
    "responsive-block-editor-addons"
  ),
  icon: "format-quote",
  category: "responsive_block_editor_addons",
  keywords: [
    __("testimonial", "responsive-block-editor-addons"),
    __("quote", "responsive-block-editor-addons"),
    __("responsive", "responsive-block-editor-addons"),
  ],
  attributes: {
    testimonialBlock: {
      type: "array",
      default: testimonialBlock,
    },
    counterId: {
      type: "string",
      default: 1,
    },
    count: {
      type: "number",
      default: ITEM_COUNT,
    },
    gutter: {
      type: "string",
      default: "medium",
    },
    testimonialAlignment: {
      type: "string",
    },
    testimonialBackgroundColor: {
      type: "string",
      default: "#f2f2f2",
    },
    testimonialTextColor: {
      type: "string",
    },
    titleFontSize: {
      type: "number",
    },
    titleLineHeight: {
      type: "number",
    },
    titleFontWeight: {
      type: "string",
    },
    titleTextTransform: {
      type: "string",
    },
    nameFontSize: {
      type: "number",
    },
    nameLineHeight: {
      type: "number",
    },
    imageWidth: {
      type: "number",
    },
    nameFontWeight: {
      type: "string",
    },
    nameTextTransform: {
      type: "string",
    },
    contentFontSize: {
      type: "number",
    },
    contentLineHeight: {
      type: "number",
      default: 1.6,
    },
    contentFontWeight: {
      type: "string",
    },
    contentTextTransform: {
      type: "string",
    },
    testimonialCiteAlign: {
      type: "string",
      default: "left-aligned",
    },
    backgroundColor: {
      type: "string",
      default: "#f2f2f2",
    },
    borderColor: {
      type: "string",
    },
    borderRadius: {
      type: "number",
      default: 2,
    },
    padding: {
      type: "number",
    },
    contentSpacing: {
      type: "number",
    },
    titleSpacing: {
      type: "number",
    },
    nameSpacing: {
      type: "number",
    },
    imageSpacing: {
      type: "number",
    },
    alignment: {
      type: "string",
      default: "center",
    },
    imageShape: {
      type: "string",
    },
    imageSize: {
      type: "string",
      default: "full",
    },
    boxShadowColor: {
      type: "string",
    },
    boxShadowHOffset: {
      type: "number",
      default: 9,
    },
    boxShadowVOffset: {
      type: "number",
      default: 9,
    },
    boxShadowBlur: {
      type: "number",
      default: 9,
    },
    boxShadowSpread: {
      type: "number",
      default: 9,
    },
    boxShadowPosition: {
      type: "string",
      default: "outset",
    },
    opacity: {
      type: "number",
      default: 0.7,
    },
    gradientDegree: {
      type: "number",
      default: 180,
    },
    bgGradient: {
      type: "boolean",
      default: false,
    },
    backgroundImage: {
      type: "string",
    },
    backgroundPosition: {
      type: "string",
    },
    backgroundSize: {
      type: "string",
    },
    backgroundRepeat: {
      type: "string",
    },
    imageHoverEffect: {
      type: "string",
    },
    bggradient: {
      type: "string",
    },
    secondaryBackgroundColor: {
      type: "string",
    },
  },
  responsive_block_editor_addons_settings_data: {
    responsive_block_editor_addons_testimonial_testimonialFontSize: {
      title: __("Font Size", "responsive-block-editor-addons"),
    },
    responsive_block_editor_addons_testimonial_testimonialCiteAlign: {
      title: __("Cite Alignment", "responsive-block-editor-addons"),
    },
    responsive_block_editor_addons_testimonial_testimonialBackgroundColor: {
      title: __("Background Color", "responsive-block-editor-addons"),
    },
    responsive_block_editor_addons_testimonial_testimonialTextColor: {
      title: __("Text Color", "responsive-block-editor-addons"),
    },
  },

  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
